/**
 * 汇付天下有限公司
 * Copyright (c) 2006-2021 ChinaPnR,Inc.All Rights Reserved.
 */
package com.huifu.bspay.sdk.demo.init;

import com.huifu.bspay.sdk.core.BasePay;
import com.huifu.bspay.sdk.core.config.MerConfig;
import com.huifu.bspay.sdk.demo.constants.DemoConstants;

import java.util.HashMap;
import java.util.Map;

/**
 * 配置实例
 *
 * <p>
 *     使用本SDK需要进行商户配置，配置由汇付分配的产品号、系统号、及对应加签、验签的密钥信息。
 * </p>
 *
 * @author kefeng.zheng
 * @version v 0.1
 */
public class MerchantConfigDemo {
    /**
     * 商户配置实例
     *
     * <p>
     *     配置调用接口时的产品号、系统号、密钥
     *     也可配置是否打开调试模式，调试模式下会有详细日志打印在控制台，联调上线时应关闭调试模式
     * </p>
     *
     */
    public static void initMerchantConfig() {
        /** debug 模式，开启后有详细的日志
         */
        BasePay.debug = true;

        /**
         * prodMode 模式，默认为生产模式，false可以使用集成测试环境
         */
        BasePay.prodMode = true;

        /**
         * 单商户模式
         */
        MerConfig merConfig = new MerConfig();
        merConfig.setProcutId(DemoConstants.DEMO_PRODUCT_ID);
        merConfig.setSysId(DemoConstants.DEMO_SYS_ID);
        merConfig.setRsaPrivateKey(DemoConstants.DEMO_RSA_PRIVATE_KEY);
        merConfig.setRsaPublicKey(DemoConstants.DEMO_RSA_PUBLIC_KEY);
        try {
            // 单商户模式merchantKey默认为default
            BasePay.initWithMerConfig(merConfig);
            // 等价于以下
            // BasePay.addMerConfig(merConfig, "default");
        } catch (Exception ex) {
            ex.printStackTrace();
        }

        /**
         * 以下为多商户模式，当申请了多套密钥配置时，采用此种方式添加多套配置
         */
        Map<String, MerConfig> merConfigs = new HashMap<>();
        MerConfig merConfig1 = new MerConfig();
        merConfig1.setProcutId(DemoConstants.DEMO_PRODUCT_ID);
        merConfig1.setSysId(DemoConstants.DEMO_SYS_ID);
        merConfig1.setRsaPrivateKey(DemoConstants.DEMO_RSA_PRIVATE_KEY);
        merConfig1.setRsaPublicKey(DemoConstants.DEMO_RSA_PUBLIC_KEY);
        MerConfig merConfig2 = new MerConfig();
        merConfig2.setProcutId(DemoConstants.DEMO_PRODUCT_ID);
        merConfig2.setSysId(DemoConstants.DEMO_SYS_ID);
        merConfig2.setRsaPrivateKey(DemoConstants.DEMO_RSA_PRIVATE_KEY);
        merConfig2.setRsaPublicKey(DemoConstants.DEMO_RSA_PUBLIC_KEY);
        // 参数1为merchantKey,是商户的唯一标识，商户自定义即可
        merConfigs.put("merchantKey1", merConfig1);
        merConfigs.put("merchantKey2", merConfig2);
        try {
            BasePay.initWithMerConfigs(merConfigs);
        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }
}
