package com.huifu.bspay.sdk.demo.merchant;

import com.alibaba.fastjson.JSON;
import com.huifu.bspay.sdk.client.BasePayClient;
import com.huifu.bspay.sdk.core.exception.BasePayException;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 功能描述:商户分账配置
 *
 * @Author wen.shao
 * @Date 2021/4/19 15:41
 */
public class AddMerSplitConfigDemo {

    /**
     * 商户分账配置-接口来源
     */
    public static void addSplitApi() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", "20210412");

        //分账业务参数
        dataMap.put("huifu_id", "6666000106120347");
        dataMap.put("product_id", "SPIN");
        //接口来源
        dataMap.put("rule_origin", "01");
        dataMap.put("refund_flag", "Y");
        dataMap.put("repeal_flag", "Y");
        dataMap.put("start_type", "0");
        dataMap.put("apply_ratio", "20");
        dataMap.put("div_flag", "Y");
        dataMap.put("async_return_url", "http://接口异步地址");

        Map<String, Object> result = new HashMap<>();
        try {
            System.out.println("商户分账配置请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            result = BasePayClient.request(dataMap, "ssproxy.addMerSplitConfig");
            // 多商户模式需指定merchantKey
            // result = BasePayClient.request(dataMap, "ssproxy.addMerSplitConfig", "yifuyun");
            System.out.println("商户分账配置返回参数：" + JSON.toJSONString(result));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) result.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) result.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息：" + subRespDesc);
        }
    }


    /**
     * 商户分账配置-页面来源
     */
    public static void addSplitPage() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", "20210412");

        //分账业务参数
        dataMap.put("huifu_id", "6666000103619396");
        dataMap.put("product_id", "ZDTEST");
        //平台来源
        dataMap.put("rule_origin", "02");
        dataMap.put("refund_flag", "Y");
        dataMap.put("repeal_flag", "Y");
        dataMap.put("start_type", "0");
        dataMap.put("apply_ratio", "20");
        dataMap.put("div_flag", "Y");
        List<Map<String, Object>> acctSplitBunchList = new ArrayList<>();
        Map<String, Object> acctSplit1 = new HashMap<String, Object>();
        acctSplit1.put("huifu_id", "6666000103619396");
        acctSplit1.put("fee_rate", "80");
        acctSplitBunchList.add(acctSplit1);
        Map<String, Object> acctSplit = new HashMap<String, Object>();
        acctSplit.put("huifu_id", "6666000003103237");
        acctSplit.put("fee_rate", "20");
        acctSplitBunchList.add(acctSplit);
        dataMap.put("acct_split_bunch_list", acctSplitBunchList);
        dataMap.put("async_return_url", "http://异步消息接收地址");

        Map<String, Object> result = new HashMap<>();
        try {
            System.out.println("商户分账配置请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            result = BasePayClient.request(dataMap, "ssproxy.addMerSplitConfig");
            // 多商户模式需指定merchantKey
            // result = BasePayClient.request(dataMap, "ssproxy.addMerSplitConfig", "yifuyun");
            System.out.println("商户分账配置返回参数：" + JSON.toJSONString(result));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) result.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("90000000".equals(subRespCode)) {
            // 审核中
            System.out.println("审核中");
        } else {
            String subRespDesc = (String) result.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息：" + subRespDesc);
        }
    }
}