package com.huifu.bspay.sdk.demo.merchant;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.huifu.bspay.sdk.client.BasePayClient;
import com.huifu.bspay.sdk.core.exception.BasePayException;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 功能描述:创建花呗活动
 *
 * @Author wen.shao
 * @Date 2021/4/19 15:41
 */
public class CreateHbSolutionDemo {

    /**
     * 创建花呗活动
     */
    public static void createHbSolution() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天

        dataMap.put("req_date", "20210412");
        dataMap.put("product_id", "SPIN");
        //渠道商汇付ID
        dataMap.put("huifu_id", "6666000018269234");
        dataMap.put("activity_name", "零利息");
        dataMap.put("start_time", "2021-02-08 00:00:00");
        dataMap.put("end_time", "2022-07-08 00:00:00");
        dataMap.put("min_money_limit", "1000");
        dataMap.put("max_money_limit", "3000");
        dataMap.put("amount_budget", "60000");

        JSONArray install_num_str_list = new JSONArray();
        install_num_str_list.add("3");
        install_num_str_list.add("6");
        install_num_str_list.add("12");
        dataMap.put("install_num_str_list", install_num_str_list);

        dataMap.put("budget_warning_money", "58000");

        JSONArray budget_warning_mail_list = new JSONArray();
        budget_warning_mail_list.add("111@alipay.com");
        dataMap.put("budget_warning_mail_list", budget_warning_mail_list);

        JSONArray budget_warning_mobile_no_list = new JSONArray();
        budget_warning_mobile_no_list.add("13940001100");
        dataMap.put("budget_warning_mobile_no_list", budget_warning_mobile_no_list);

        //子门店信息集合
        List<Map<String, Object>> sub_shop_info_list = new ArrayList();
        Map<String, Object> sub_shop_info = new HashMap<String, Object>();
        sub_shop_info.put("sub_mer_id", "A1035134718833585758");
        sub_shop_info.put("sub_mer_name", "上海市浦东新区东明路街道悠佰佳休闲食品商行");
        sub_shop_info.put("fee_type", "02");
        sub_shop_info_list.add(sub_shop_info);
        dataMap.put("sub_shop_info_list", sub_shop_info_list);

        Map<String, Object> result = new HashMap<>();
        try {
            System.out.println("创建花呗分期活动请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            result = BasePayClient.request(dataMap, "ssproxy.pcredit.createHbPcreditSolution");
            // 多商户模式需指定merchantKey
            // result = BasePayClient.request(dataMap, "ssproxy.pcredit.createHbPcreditSolution", "yifuyun");
            System.out.println("创建花呗分期活动返回参数：" + JSON.toJSONString(result));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) result.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) result.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息：" + subRespDesc);
        }
    }
}