package com.huifu.bspay.sdk.demo.merchant;

import com.alibaba.fastjson.JSON;
import com.huifu.bspay.sdk.client.BasePayClient;
import com.huifu.bspay.sdk.core.exception.BasePayException;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 功能描述:修改商户信息
 *
 * @Author wen.shao
 * @Date 2021/4/19 15:41
 */
public class ModifyMerRegDemo {

    /**
     * 修改商户信息
     */
    public static void modify() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", "20210412");

        //涉及安全，这里对敏感数据进行脱敏了，如果需要看进件成功测试效果，请用真实数据测试
        String certName = "王**";
        String certNo = "130302************";
        String cardNo = "6217880800006078416";

        //商铺基本信息
        dataMap.put("huifu_id", "6666000106120347");
        dataMap.put("upper_huifu_id", "6666000018269234");
        dataMap.put("short_name", "悠佰佳休闲食品商行");
        //营业执照信息
        dataMap.put("license_validity_type", "1");
        dataMap.put("license_begin_date", "20190603");
        dataMap.put("license_end_date", "");
        dataMap.put("reg_prov_id", "310000");
        dataMap.put("reg_area_id", "310100");
        dataMap.put("reg_district_id", "310115");
        dataMap.put("reg_detail", "浦东新区长清路1881号一层");
        //营业执照法人信息
        dataMap.put("legal_name", certName);
        dataMap.put("legal_cert_type", "00");
        dataMap.put("legal_cert_no", certNo);
        dataMap.put("legal_cert_validity_type", "1");
        dataMap.put("legal_cert_begin_date", "20121201");
        dataMap.put("legal_cert_end_date", "20301201");
        dataMap.put("prov_id", "310000");
        dataMap.put("area_id", "310100");
        dataMap.put("district_id", "310115");
        dataMap.put("detail_addr", "浦东新区长清路1881号一层");
        dataMap.put("contact_name", "联系人");
        dataMap.put("contact_mobile_no", "13661955468");
        dataMap.put("contact_email", "jeff.peng@huifu.com");
        dataMap.put("service_phone", "021-121111221");
        dataMap.put("sms_send_flag", "1");
        dataMap.put("busi_type", "1");
        dataMap.put("receipt_name", "悠佰佳休闲食品商行");
        dataMap.put("mcc", "5411");
        dataMap.put("async_return_url", "http://ip/sspm/testVirgo");
        //结算配置
        Map<String, Object> setttleInfo = new HashMap<String, Object>();
        setttleInfo.put("settle_cycle", "T1");
        setttleInfo.put("settle_status", "1");
//        dataMap.put("settle_config",setttleInfo);

        //取现配置
        List<Map<String, Object>> cashList = new ArrayList();
        Map<String, Object> cashInfo = new HashMap<String, Object>();
        cashInfo.put("cash_type", "T1");
        cashInfo.put("fix_amt", "0.01");
        cashList.add(cashInfo);
        Map<String, Object> cashInfo1 = new HashMap<String, Object>();
        cashInfo1.put("cash_type", "D0");
        cashInfo1.put("fix_amt", "0.01");
        cashList.add(cashInfo1);
        dataMap.put("cash_config", cashList);

        //结算卡配置
        Map<String, Object> cardInfo = new HashMap<String, Object>();
        cardInfo.put("card_type", "0");
        cardInfo.put("card_name", "上海市浦东新区东明路街道悠佰佳休闲食品商行");
        cardInfo.put("card_no", cardNo);
        cardInfo.put("prov_id", "310000");
        cardInfo.put("area_id", "310100");
        cardInfo.put("bank_code", "01030000");
        cardInfo.put("branch_code", "103290040169");
        cardInfo.put("branch_name", "中国农业银行股份有限公司上海马当路支行");
//        cardInfo.put("cert_type", "00");
//        cardInfo.put("cert_no",certNo);
//        cardInfo.put("cert_validity_type", "1");
//        cardInfo.put("cert_begin_date", "20121201");
//        cardInfo.put("cert_end_date", "20301201");
        cardInfo.put("mp", "13700000214");
        dataMap.put("card_info", cardInfo);

        Map<String, Object> result = new HashMap<>();
        try {
            System.out.println("商户信息修改请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            result = BasePayClient.request(dataMap, "ssproxy.merModify");
            // 多商户模式需指定merchantKey
            // result = BasePayClient.request(dataMap, "ssproxy.merModify", "yifuyun");
            System.out.println("商户信息修改返回参数：" + JSON.toJSONString(result));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) result.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("90000000".equals(subRespCode)) {
            // 审核中
            System.out.println("审核中");
        } else {
            String subRespDesc = (String) result.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息：" + subRespDesc);
        }
    }
}