package com.huifu.bspay.sdk.demo.merchant;

import com.alibaba.fastjson.JSON;
import com.huifu.bspay.sdk.client.BasePayClient;
import com.huifu.bspay.sdk.core.exception.BasePayException;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 功能描述:商户业务开通
 *
 * @Author wen.shao
 * @Date 2021/4/19 15:41
 */
public class RegMerBusiDemo {

    /**
     * 商户业务开通
     */
    public static void regMerBusiInfo() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", "20210412");

        dataMap.put("huifu_id", "6666000106120347");
        dataMap.put("upper_huifu_id", "6666000018269234");

        //支付宝入驻
        List<Map<String, Object>> aliConfList = new ArrayList<>();
        Map<String, Object> aliConf = new HashMap<String, Object>();
        aliConf.put("pay_scene", "1");
        aliConf.put("fee_rate", "0.01");
        aliConf.put("mcc", "2015091000052157");
        aliConfList.add(aliConf);
        dataMap.put("ali_conf_list", aliConfList);
        //微信入驻
        List<Map<String, Object>> wxConfList = new ArrayList<>();
        Map<String, Object> wxConf1 = new HashMap<String, Object>();
        wxConf1.put("pay_scene", "1");
        wxConf1.put("fee_rate", "0.01");
        wxConf1.put("fee_rule_id", "762");
        wxConfList.add(wxConf1);
        Map<String, Object> wxConf3 = new HashMap<String, Object>();
        wxConf3.put("pay_scene", "3");
        wxConf3.put("fee_rate", "0.01");
        wxConf3.put("fee_rule_id", "762");
        wxConfList.add(wxConf3);
        Map<String, Object> wxConf = new HashMap<String, Object>();
        wxConf.put("pay_scene", "2");
        wxConf.put("fee_rate", "0.01");
        wxConf.put("fee_rule_id", "762");
        wxConfList.add(wxConf);
        dataMap.put("wx_conf_list", wxConfList);
        //银行卡开通
        Map<String, Object> bankCardConf = new HashMap<String, Object>();
        bankCardConf.put("mcc", "5411");
        bankCardConf.put("debit_fee_rate", "0.01");
        bankCardConf.put("debit_fee_limit", "18");
        bankCardConf.put("credit_fee_rate", "0.55");
        bankCardConf.put("cloud_debit_fee_rate_up", "0.55");
        bankCardConf.put("cloud_debit_fee_limit_up", "18");
        bankCardConf.put("cloud_credit_fee_rate_up", "0.55");
        bankCardConf.put("cloud_debit_fee_rate_down", "0.38");
        bankCardConf.put("cloud_credit_fee_rate_down", "0.38");
        bankCardConf.put("is_open_small_flag", "0");
        bankCardConf.put("small_free_amt", "300");
        bankCardConf.put("small_fee_amt", "0.11");
        dataMap.put("bank_card_conf", bankCardConf);
        //银联开通
        List<Map<String, Object>> unionConfList = new ArrayList<>();
        Map<String, Object> unionConf = new HashMap<String, Object>();
        unionConf.put("mcc", "5411");
        unionConf.put("credit_fee_rate_down", "0.38");
        unionConf.put("credit_fee_rate_up", "0.58");
        unionConf.put("debit_fee_limit_up", "18");
        unionConf.put("debit_fee_rate_down", "0.38");
        unionConf.put("debit_fee_rate_up", "0.58");
        unionConfList.add(unionConf);
        dataMap.put("union_conf_list", unionConfList);
        //分期业务
        Map<String, Object> hbFqFeeConfig = new HashMap<String, Object>();
        hbFqFeeConfig.put("pay_scene", "1");
        hbFqFeeConfig.put("six_period", "4.5000");
        hbFqFeeConfig.put("acq_six_period", "2.16");
        dataMap.put("hb_fq_fee_config", hbFqFeeConfig);
        dataMap.put("async_return_url", "http://异步通知接收地址");
        dataMap.put("quick_flag", "Y");
//        dataMap.put("withhold_flag","Y");
        dataMap.put("online_flag", "Y");
        dataMap.put("alipay_pre_auth_flag", "Y");

        Map<String, Object> balance_pay_config = new HashMap<String, Object>();
        balance_pay_config.put("fee_rate", "0.01");
        balance_pay_config.put("fee_fix_amt", "0.01");
        dataMap.put("balance_pay_config", balance_pay_config);

        Map<String, Object> result = new HashMap<>();
        try {
            System.out.println("商户业务开通请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            result = BasePayClient.request(dataMap, "ssproxy.regMerBusiInfo");
            // 多商户模式需指定merchantKey
            // result = BasePayClient.request(dataMap, "ssproxy.regMerBusiInfo", "yifuyun");
            System.out.println("商户业务开通返回参数：" + JSON.toJSONString(result));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) result.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("90000000".equals(subRespCode)) {
            // 审核中
            System.out.println("审核中");
        } else {
            String subRespDesc = (String) result.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息：" + subRespDesc);
        }
    }
}