package com.huifu.bspay.sdk.demo.trans;

import com.alibaba.fastjson.JSON;
import com.huifu.bspay.sdk.client.BasePayClient;
import com.huifu.bspay.sdk.demo.constants.DemoConstants;
import com.huifu.bspay.sdk.core.exception.BasePayException;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @ClassName AcctPaymentDemo.java
 * @Description
 * @Author jili.hua
 * @Date 2021/4/14 9:45
 * @Version 1.0
 **/
public class AcctPaymentDemo {

    /**
     * 余额支付接口
     */
    public static void executeAcctPayment() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", "20210422");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 出款商户号
        dataMap.put("out_huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 订单金额
        dataMap.put("ord_amt", "0.01");
        // 设备信息
        Map<String, String> deviceInfo = new HashMap<>();
        deviceInfo.put("device_type", "1");// 1:手机2:平板3:手表4:PC
        deviceInfo.put("device_ip", "139.207.19.246 ");
        dataMap.put("device_info", JSON.toJSONString(deviceInfo));

        // 风控信息
        Map<String, Object> riskCheckInfo = new HashMap<>();
        riskCheckInfo.put("transferType", "余额支付");
        // 注意，风控信息为JSON字符串
        dataMap.put("risk_check_info", JSON.toJSONString(riskCheckInfo));

        // 分账串
        List<Map<String, String>> acctInfos = new ArrayList<>();
        Map<String, String> acctInfo1 = new HashMap<>();
        // 分账商户号1
        acctInfo1.put("in_huifu_id", DemoConstants.DIV_HUIFU_ID);
        // 分账金额1
        acctInfo1.put("div_amt", "0.01");
        acctInfos.add(acctInfo1);
        Map<String, Object> acctSplitBunch = new HashMap<>();
        acctSplitBunch.put("acct_infos", acctInfos);
        dataMap.put("acct_payment_split_bunch", acctSplitBunch);

        Map<String, Object> acctPayment = new HashMap<>();
        try {
            System.out.println("余额支付请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            acctPayment = BasePayClient.request(dataMap, "topat.acctPayment");
            // 多商户模式需指定merchantKey
            // acctPayment = BasePayClient.request(dataMap, "topat.acctPayment", "merchantKey1");
            System.out.println("余额支付返回参数：" + JSON.toJSONString(acctPayment));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) acctPayment.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) acctPayment.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 余额支付查询接口
     */
    public static void executeAcctPaymentQuery() {
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 原交易请求流水号
        dataMap.put("org_req_seq_id", "2021042211045701234567890");
        // 原交易请求日期
        dataMap.put("org_req_date", "20210422");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);

        Map<String, Object> acctPaymentInfo = new HashMap<>();
        try {
            System.out.println("余额支付查询请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            acctPaymentInfo = BasePayClient.request(dataMap, "topat.acctPaymentQuery");
            // 多商户模式需指定merchantKey
            // acctPaymentInfo = BasePayClient.request(dataMap, "topat.acctPaymentQuery", "merchantKey1");
            System.out.println("余额支付查询返回参数：" + JSON.toJSONString(acctPaymentInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) acctPaymentInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) acctPaymentInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 余额支付退款接口
     */
    public static void executeAcctPaymentRefund() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", "20210422");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 原交易请求流水号
        dataMap.put("org_req_seq_id", "2021042211045701234567890");
        // 原交易请求时间
        dataMap.put("org_req_date", "20210422");
        // 退款金额
        dataMap.put("ord_amt", "0.01");

        // 风控信息
        Map<String, Object> riskCheckInfo = new HashMap<>();
        riskCheckInfo.put("transferType", "余额支付退款");
        // 注意，风控信息为JSON字符串
        dataMap.put("risk_check_info", JSON.toJSONString(riskCheckInfo));

        // 分账串
        List<Map<String, String>> acctInfos = new ArrayList<>();
        Map<String, String> acctInfo1 = new HashMap<>();
        // 分账商户号1
        acctInfo1.put("in_huifu_id", DemoConstants.DIV_HUIFU_ID);
        // 分账金额1
        acctInfo1.put("div_amt", "0.01");
        acctInfos.add(acctInfo1);
        Map<String, Object> acctSplitBunch = new HashMap<>();
        acctSplitBunch.put("acct_infos", acctInfos);
        dataMap.put("acct_payment_split_bunch", acctSplitBunch);

        Map<String, Object> acctRefund = new HashMap<>();
        try {
            System.out.println("余额支付退款请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            acctRefund = BasePayClient.request(dataMap, "topat.acctPaymentRefund");
            // 多商户模式需指定merchantKey
            // acctRefund = BasePayClient.request(dataMap, "topat.acctPaymentRefund", "merchantKey1");
            System.out.println("余额支付退款返回参数：" + JSON.toJSONString(acctRefund));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) acctRefund.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) acctRefund.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 余额支付退款查询接口
     */
    public static void executeAcctPaymentRefundQuery() {
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 退款请求流水号
        dataMap.put("req_seq_id", "2021042211065701234567890");
        // 退款请求时间
        dataMap.put("req_date", "20210422");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);

        Map<String, Object> acctPaymentRefundInfo = new HashMap<>();
        try {
            System.out.println("余额支付退款查询请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            acctPaymentRefundInfo = BasePayClient.request(dataMap, "topat.acctPaymentRefundQuery");
            // 多商户模式需指定merchantKey
            // acctPaymentRefundInfo = BasePayClient.request(dataMap, "topat.acctPaymentRefundQuery", "merchantKey1");
            System.out.println("余额支付退款查询返回参数：" + JSON.toJSONString(acctPaymentRefundInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) acctPaymentRefundInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) acctPaymentRefundInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }
}
