/**
 * 汇付天下有限公司
 * Copyright (c) 2006-2021 ChinaPnR,Inc.All Rights Reserved.
 */
package com.huifu.bspay.sdk.demo.trans;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.huifu.bspay.sdk.client.BasePayClient;
import com.huifu.bspay.sdk.demo.constants.DemoConstants;
import com.huifu.bspay.sdk.core.exception.BasePayException;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.HashMap;
import java.util.Map;

/**
 * 聚合扫码类交易调用实例
 */
public class AggregatePaymentDemo {
    /**
     * 微信公众号支付
     */
    public static void executeWxJsApi () {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 系统号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 商户订单号，需保证商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("mer_ord_id", nowStr + "1234567890");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 交易类型
        // 微信公众号-T_JSAPI 小程序-T_MINIAPP 支付宝JS-A_JSAPI 支付宝正扫-A_NATIVE 银联正扫-U_NATIVE 银联JS-U_JSAPI
        dataMap.put("trade_type", "T_JSAPI");
        // 交易金额
        dataMap.put("trans_amt", "0.02");
        // 商品描述
        dataMap.put("goods_desc", "测试商品");
        // 设备信息
        JSONObject terminalDeviceInfo = new JSONObject();
        terminalDeviceInfo.put("device_type", "4");
        terminalDeviceInfo.put("device_ip", "139.207.19.246");
        dataMap.put("terminal_device_info", terminalDeviceInfo);
        // 风控信息
        Map<String, String> riskMngInfo = new HashMap<>();
        riskMngInfo.put("subTradeType", "4300");
        Map<String, Object> riskCheckInfo = new HashMap<>();
        riskCheckInfo.put("riskMngInfo", riskMngInfo);
        riskCheckInfo.put("ipAddr", "139.207.19.246");
        // 注意，风控信息为JSON字符串
        // dataMap.put("risk_check_info", JSON.toJSONString(riskCheckInfo));
        dataMap.put("risk_check_info", riskCheckInfo);
        // 异步通知地址
        dataMap.put("notify_url", "virgo://http://www.vclinker.com");
        // 微信用户子标识 微信JS支付此参数必传
        dataMap.put("sub_openid", DemoConstants.WX_SUB_OPEN_ID);
        // 买家的支付宝唯一用户号 支付宝JS支付，buyer_id与buyer_logon_id必送其中1个
        dataMap.put("buyer_id", "");
        // 买家支付宝账号 支付宝JS支付，buyer_id与buyer_logon_id必送其中1个
        dataMap.put("buyer_logon_id", "");
        // 用户在云闪付APP上的标识号，用来提供给收款方， 并在收款方发起交易时回传给付款方。（银联JS支付必填）
        // 通过获取银联用户标识获取
        dataMap.put("user_id", "");
        // 持卡人确认付款时的IP地址，用于防钓鱼。（银联JS支付必填）
        dataMap.put("client_ip", "");
        // 交易有效期
        cl.add(Calendar.MINUTE, 2);
        dataMap.put("time_expire", sdf.format(cl.getTime()));
        // 指定支付方式 是否禁止用户使用信用卡支付。默认不禁用，若禁止请填1
        dataMap.put("limit_pay", "1");
        // 延时标志 1为延迟 0为不延迟
        dataMap.put("is_delay_acct", "0");
        // 传入分帐遇到优惠的处理规则 1-按比例分 2-按顺序保障 3-只给交易商户
        dataMap.put("term_div_coupon_type", "3");
        // 分账串
        JSONObject acctSplitBunch = new JSONObject();
        JSONArray acctInfos = new JSONArray();
        // 分账方1
        JSONObject acctInfo = new JSONObject();
        acctInfo.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        acctInfo.put("div_amt", "0.01");
        acctInfos.add(acctInfo);
        // 分账方2
        acctInfo = new JSONObject();
        acctInfo.put("huifu_id", DemoConstants.DIV_HUIFU_ID);
        acctInfo.put("div_amt", "0.01");
        acctInfos.add(acctInfo);
        acctSplitBunch.put("acct_infos", acctInfos);
        dataMap.put("acct_split_bunch", acctSplitBunch);
        // 商户私有域
        dataMap.put("mer_priv", "");
        // 微信扩展参数集合
        Map<String, String> wxData = new HashMap<>();
        // 子商户公众账号ID
        wxData.put("sub_appid", DemoConstants.WX_SUB_APP_ID);
        // dataMap.put("wx_data", wxData);
        // 支付宝扩展参数集合
        dataMap.put("alipay_data", "");
        // 银联扩展参数集合
        dataMap.put("unionpay_data", "");
        // 手续费类型 01:标准费率线上,02:标准费率线下,03:非盈利费率,04:缴费费率,05:保险费率,06:行业活动费率,07:校园餐饮费率,08:K12中小幼费率
        // 不送时取业务入驻配置的默认费率
        dataMap.put("pay_scene", "02");
        // 分期贴息类型，1:商户贴息，默认商户不贴息。注意：当此处填1时，花呗商户承担比例hb_fq_seller_percent只能填0
        dataMap.put("fq_mer_discount_flag", 0);
        // 交易备注
        dataMap.put("remark", "");

        Map<String, Object> pullPayInfo = new HashMap<>();
        try {
            System.out.println("聚合正扫请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            pullPayInfo = BasePayClient.request(dataMap, "top.trans.pullPayInfo");
            // 多商户模式需指定merchantKey
            // pullPayInfo = BasePayClient.request(dataMap, "top.trans.pullPayInfo", "merchantKey1");
            System.out.println("聚合正扫返回参数：" + JSON.toJSONString(pullPayInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) pullPayInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("00000100".equals(subRespCode)) {
            // 聚合正扫返回处理中
            String payInfo = (String) pullPayInfo.get("pay_info");
            System.out.println("pay_info :" + payInfo);
        } else {
            String subRespDesc = (String) pullPayInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 支付宝JS支付
     */
    public static void executeAliJsApi () {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 系统号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 商户订单号，需保证商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("mer_ord_id", nowStr + "1234567890");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 交易类型
        // 微信公众号-T_JSAPI 小程序-T_MINIAPP 支付宝JS-A_JSAPI 支付宝正扫-A_NATIVE 银联正扫-U_NATIVE 银联JS-U_JSAPI
        dataMap.put("trade_type", "A_JSAPI");
        // 交易金额
        dataMap.put("trans_amt", "0.02");
        // 商品描述
        dataMap.put("goods_desc", "测试商品");
        // 设备信息
        JSONObject terminalDeviceInfo = new JSONObject();
        terminalDeviceInfo.put("device_type", "4");
        terminalDeviceInfo.put("device_ip", "139.207.19.246");
        dataMap.put("terminal_device_info", terminalDeviceInfo);
        // 风控信息
        Map<String, String> riskMngInfo = new HashMap<>();
        riskMngInfo.put("subTradeType", "4300");
        Map<String, Object> riskCheckInfo = new HashMap<>();
        riskCheckInfo.put("riskMngInfo", riskMngInfo);
        riskCheckInfo.put("ipAddr", "139.207.19.246");
        // 注意，风控信息为JSON字符串
        // dataMap.put("risk_check_info", JSON.toJSONString(riskCheckInfo));
        dataMap.put("risk_check_info", riskCheckInfo);
        // 异步通知地址
        dataMap.put("notify_url", "virgo://http://www.vclinker.com");
        // 微信用户子标识 微信JS支付此参数必传
        dataMap.put("sub_openid", "");
        // 买家的支付宝唯一用户号 支付宝JS支付，buyer_id必送
        dataMap.put("buyer_id", DemoConstants.ALI_BUYER_ID);
        // 用户在云闪付APP上的标识号，用来提供给收款方， 并在收款方发起交易时回传给付款方。（银联JS支付必填）
        // 通过获取银联用户标识获取
        dataMap.put("user_id", "");
        // 持卡人确认付款时的IP地址，用于防钓鱼。（银联JS支付必填）
        dataMap.put("client_ip", "");
        // 交易有效期
        cl.add(Calendar.MINUTE, 2);
        dataMap.put("time_expire", sdf.format(cl.getTime()));
        // 指定支付方式 是否禁止用户使用信用卡支付。默认不禁用，若禁止请填1
        dataMap.put("limit_pay", "1");
        // 延时标志 1为延迟 0为不延迟
        dataMap.put("is_delay_acct", "0");
        // 传入分帐遇到优惠的处理规则 1-按比例分 2-按顺序保障 3-只给交易商户
        dataMap.put("term_div_coupon_type", "3");
        // 分账串
        JSONObject acctSplitBunch = new JSONObject();
        JSONArray acctInfos = new JSONArray();
        // 分账方1
        JSONObject acctInfo = new JSONObject();
        acctInfo.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        acctInfo.put("div_amt", "0.01");
        acctInfos.add(acctInfo);
        // 分账方2
        acctInfo = new JSONObject();
        acctInfo.put("huifu_id", DemoConstants.DIV_HUIFU_ID);
        acctInfo.put("div_amt", "0.01");
        acctInfos.add(acctInfo);
        acctSplitBunch.put("acct_infos", acctInfos);
        dataMap.put("acct_split_bunch", acctSplitBunch);
        // 商户私有域
        dataMap.put("mer_priv", "");
        // 微信扩展参数集合
        dataMap.put("wx_data", "");
        // 支付宝扩展参数集合
        dataMap.put("alipay_data", "");
        // 银联扩展参数集合
        dataMap.put("unionpay_data", "");
        // 手续费类型 01:标准费率线上,02:标准费率线下,03:非盈利费率,04:缴费费率,05:保险费率,06:行业活动费率,07:校园餐饮费率,08:K12中小幼费率
        // 不送时取业务入驻配置的默认费率
        dataMap.put("pay_scene", "02");
        // 分期贴息类型，1:商户贴息，默认商户不贴息。注意：当此处填1时，花呗商户承担比例hb_fq_seller_percent只能填0
        dataMap.put("fq_mer_discount_flag", 0);
        // 交易备注
        dataMap.put("remark", "");

        Map<String, Object> pullPayInfo = new HashMap<>();
        try {
            System.out.println("聚合正扫请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            pullPayInfo = BasePayClient.request(dataMap, "top.trans.pullPayInfo");
            // 多商户模式需指定merchantKey
            // pullPayInfo = BasePayClient.request(dataMap, "top.trans.pullPayInfo", "merchantKey1");
            System.out.println("聚合正扫返回参数：" + JSON.toJSONString(pullPayInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) pullPayInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("00000100".equals(subRespCode)) {
            // 聚合正扫返回处理中
            String payInfo = (String) pullPayInfo.get("pay_info");
            System.out.println("pay_info :" + payInfo);
        } else {
            String subRespDesc = (String) pullPayInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 银联JS支付
     */
    public static void executeUnionPayJsApi () {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 系统号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 商户订单号，需保证商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("mer_ord_id", nowStr + "1234567890");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 交易类型
        // 微信公众号-T_JSAPI 小程序-T_MINIAPP 支付宝JS-A_JSAPI 支付宝正扫-A_NATIVE 银联正扫-U_NATIVE 银联JS-U_JSAPI
        dataMap.put("trade_type", "U_JSAPI");
        // 交易金额
        dataMap.put("trans_amt", "0.02");
        // 商品描述
        dataMap.put("goods_desc", "测试商品");
        // 设备信息
        JSONObject terminalDeviceInfo = new JSONObject();
        terminalDeviceInfo.put("device_type", "4");
        terminalDeviceInfo.put("device_ip", "139.207.19.246");
        dataMap.put("terminal_device_info", terminalDeviceInfo);
        // 风控信息
        Map<String, String> riskMngInfo = new HashMap<>();
        riskMngInfo.put("subTradeType", "4300");
        Map<String, Object> riskCheckInfo = new HashMap<>();
        riskCheckInfo.put("riskMngInfo", riskMngInfo);
        riskCheckInfo.put("ipAddr", "139.207.19.246");
        // 注意，风控信息为JSON字符串
        // dataMap.put("risk_check_info", JSON.toJSONString(riskCheckInfo));
        dataMap.put("risk_check_info", riskCheckInfo);
        // 异步通知地址
        dataMap.put("notify_url", "virgo://http://www.vclinker.com");
        // 微信用户子标识 微信JS支付此参数必传
        dataMap.put("sub_openid", "");
        // 买家的支付宝唯一用户号 支付宝JS支付，buyer_id必送
        dataMap.put("buyer_id", "");
        // 用户在云闪付APP上的标识号，用来提供给收款方， 并在收款方发起交易时回传给付款方。（银联JS支付必填）
        // 通过获取银联用户标识获取
        dataMap.put("user_id", DemoConstants.UNIONPAY_USER_ID);
        // 持卡人确认付款时的IP地址，用于防钓鱼。（银联JS支付必填）
        dataMap.put("client_ip", "");
        // 交易有效期
        cl.add(Calendar.MINUTE, 2);
        dataMap.put("time_expire", sdf.format(cl.getTime()));
        // 指定支付方式 是否禁止用户使用信用卡支付。默认不禁用，若禁止请填1
        dataMap.put("limit_pay", "1");
        // 延时标志 1为延迟 0为不延迟
        dataMap.put("is_delay_acct", "0");
        // 传入分帐遇到优惠的处理规则 1-按比例分 2-按顺序保障 3-只给交易商户
        dataMap.put("term_div_coupon_type", "3");
        // 分账串
        JSONObject acctSplitBunch = new JSONObject();
        JSONArray acctInfos = new JSONArray();
        // 分账方1
        JSONObject acctInfo = new JSONObject();
        acctInfo.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        acctInfo.put("div_amt", "0.01");
        acctInfos.add(acctInfo);
        // 分账方2
        acctInfo = new JSONObject();
        acctInfo.put("huifu_id", DemoConstants.DIV_HUIFU_ID);
        acctInfo.put("div_amt", "0.01");
        acctInfos.add(acctInfo);
        acctSplitBunch.put("acct_infos", acctInfos);
        dataMap.put("acct_split_bunch", acctSplitBunch);
        // 商户私有域
        dataMap.put("mer_priv", "");
        // 微信扩展参数集合
        dataMap.put("wx_data", "");
        // 支付宝扩展参数集合
        dataMap.put("alipay_data", "");
        // 银联扩展参数集合
        dataMap.put("unionpay_data", "");
        // 手续费类型 01:标准费率线上,02:标准费率线下,03:非盈利费率,04:缴费费率,05:保险费率,06:行业活动费率,07:校园餐饮费率,08:K12中小幼费率
        // 不送时取业务入驻配置的默认费率
        dataMap.put("pay_scene", "02");
        // 分期贴息类型，1:商户贴息，默认商户不贴息。注意：当此处填1时，花呗商户承担比例hb_fq_seller_percent只能填0
        dataMap.put("fq_mer_discount_flag", 0);
        // 交易备注
        dataMap.put("remark", "");

        Map<String, Object> pullPayInfo = new HashMap<>();
        try {
            System.out.println("聚合正扫请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            pullPayInfo = BasePayClient.request(dataMap, "top.trans.pullPayInfo");
            // 多商户模式需指定merchantKey
            // pullPayInfo = BasePayClient.request(dataMap, "top.trans.pullPayInfo", "merchantKey1");
            System.out.println("聚合正扫返回参数：" + JSON.toJSONString(pullPayInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) pullPayInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("00000100".equals(subRespCode)) {
            // 聚合正扫返回处理中
            String payInfo = (String) pullPayInfo.get("pay_info");
            System.out.println("pay_info :" + payInfo);
        } else {
            String subRespDesc = (String) pullPayInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 微信小程序支付
     */
    public static void executeWxMiniApp () {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 系统号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 商户订单号，需保证商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("mer_ord_id", nowStr + "1234567890");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 交易类型
        // 微信公众号-T_JSAPI 小程序-T_MINIAPP 支付宝JS-A_JSAPI 支付宝正扫-A_NATIVE 银联正扫-U_NATIVE 银联JS-U_JSAPI
        dataMap.put("trade_type", "T_MINIAPP");
        // 交易金额
        dataMap.put("trans_amt", "0.02");
        // 商品描述
        dataMap.put("goods_desc", "测试商品");
        // 设备信息
        JSONObject terminalDeviceInfo = new JSONObject();
        terminalDeviceInfo.put("device_type", "4");
        terminalDeviceInfo.put("device_ip", "139.207.19.246");
        dataMap.put("terminal_device_info", terminalDeviceInfo);
        // 风控信息
        Map<String, String> riskMngInfo = new HashMap<>();
        riskMngInfo.put("subTradeType", "4300");
        Map<String, Object> riskCheckInfo = new HashMap<>();
        riskCheckInfo.put("riskMngInfo", riskMngInfo);
        riskCheckInfo.put("ipAddr", "139.207.19.246");
        // 注意，风控信息为JSON字符串
        // dataMap.put("risk_check_info", JSON.toJSONString(riskCheckInfo));
        dataMap.put("risk_check_info", riskCheckInfo);
        // 异步通知地址
        dataMap.put("notify_url", "virgo://http://www.vclinker.com");
        // 微信用户子标识 微信JS支付此参数必传
        dataMap.put("sub_openid", DemoConstants.WX_SUB_OPEN_ID);
        // 买家的支付宝唯一用户号 支付宝JS支付，buyer_id与buyer_logon_id必送其中1个
        dataMap.put("buyer_id", "");
        // 买家支付宝账号 支付宝JS支付，buyer_id与buyer_logon_id必送其中1个
        dataMap.put("buyer_logon_id", "");
        // 用户在云闪付APP上的标识号，用来提供给收款方， 并在收款方发起交易时回传给付款方。（银联JS支付必填）
        // 通过获取银联用户标识获取
        dataMap.put("user_id", "");
        // 持卡人确认付款时的IP地址，用于防钓鱼。（银联JS支付必填）
        dataMap.put("client_ip", "");
        // 交易有效期
        cl.add(Calendar.MINUTE, 2);
        dataMap.put("time_expire", sdf.format(cl.getTime()));
        // 指定支付方式 是否禁止用户使用信用卡支付。默认不禁用，若禁止请填1
        dataMap.put("limit_pay", "1");
        // 延时标志 1为延迟 0为不延迟
        dataMap.put("is_delay_acct", "0");
        // 传入分帐遇到优惠的处理规则 1-按比例分 2-按顺序保障 3-只给交易商户
        dataMap.put("term_div_coupon_type", "3");
        // 分账串
        JSONObject acctSplitBunch = new JSONObject();
        JSONArray acctInfos = new JSONArray();
        // 分账方1
        JSONObject acctInfo = new JSONObject();
        acctInfo.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        acctInfo.put("div_amt", "0.01");
        acctInfos.add(acctInfo);
        // 分账方2
        acctInfo = new JSONObject();
        acctInfo.put("huifu_id", DemoConstants.DIV_HUIFU_ID);
        acctInfo.put("div_amt", "0.01");
        acctInfos.add(acctInfo);
        acctSplitBunch.put("acct_infos", acctInfos);
        dataMap.put("acct_split_bunch", acctSplitBunch);
        // 商户私有域
        dataMap.put("mer_priv", "");
        // 微信扩展参数集合
        JSONObject wxData = new JSONObject();
        // 子商户公众账号ID，上送小程序appid
        wxData.put("sub_appid", DemoConstants.WX_SUB_APP_ID);
        // 单品列表
        JSONArray goodsDetailList = new JSONArray();
        // 单品信息1
        JSONObject goodsDetail = new JSONObject();
        // 商品1id
        goodsDetail.put("goods_id", "test01");
        // 商品1名字
        goodsDetail.put("goods_name", "测试商品1");
        // 商品1数量
        goodsDetail.put("quantity", 1);
        // 商品1单价
        goodsDetail.put("price", "0.01");
        goodsDetailList.add(goodsDetail);
        // 单品信息2
        goodsDetail = new JSONObject();
        // 商品2id
        goodsDetail.put("goods_id", "test02");
        // 商品2名字
        goodsDetail.put("goods_name", "测试商品2");
        // 商品2数量
        goodsDetail.put("quantity", 1);
        // 商品2单价
        goodsDetail.put("price", "0.01");
        goodsDetailList.add(goodsDetail);
        // 商品详情
        JSONObject detail = new JSONObject();
        detail.put("goods_detail", goodsDetailList);
        wxData.put("detail", detail);
        dataMap.put("wx_data", wxData);
        // 支付宝扩展参数集合
        dataMap.put("alipay_data", "");
        // 银联扩展参数集合
        dataMap.put("unionpay_data", "");
        // 手续费类型 01:标准费率线上,02:标准费率线下,03:非盈利费率,04:缴费费率,05:保险费率,06:行业活动费率,07:校园餐饮费率,08:K12中小幼费率
        // 不送时取业务入驻配置的默认费率
        dataMap.put("pay_scene", "02");
        // 分期贴息类型，1:商户贴息，默认商户不贴息。注意：当此处填1时，花呗商户承担比例hb_fq_seller_percent只能填0
        dataMap.put("fq_mer_discount_flag", 0);
        // 交易备注
        dataMap.put("remark", "");

        Map<String, Object> pullPayInfo = new HashMap<>();
        try {
            System.out.println("聚合正扫请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            pullPayInfo = BasePayClient.request(dataMap, "top.trans.pullPayInfo");
            // 多商户模式需指定merchantKey
            // pullPayInfo = BasePayClient.request(dataMap, "top.trans.pullPayInfo", "merchantKey1");
            System.out.println("聚合正扫返回参数：" + JSON.toJSONString(pullPayInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) pullPayInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("00000100".equals(subRespCode)) {
            // 聚合正扫返回处理中
            String payInfo = (String) pullPayInfo.get("pay_info");
            System.out.println("pay_info :" + payInfo);
        } else {
            String subRespDesc = (String) pullPayInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 支付宝正扫Native支付
     */
    public static void executeAliNative () {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 系统号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 商户订单号，需保证商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("mer_ord_id", nowStr + "1234567890");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 交易类型
        // 微信公众号-T_JSAPI 小程序-T_MINIAPP 支付宝JS-A_JSAPI 支付宝正扫-A_NATIVE 银联正扫-U_NATIVE 银联JS-U_JSAPI
        dataMap.put("trade_type", "A_NATIVE");
        // 交易金额
        dataMap.put("trans_amt", "0.02");
        // 商品描述
        dataMap.put("goods_desc", "测试商品");
        // 设备信息
        JSONObject terminalDeviceInfo = new JSONObject();
        terminalDeviceInfo.put("device_type", "4");
        terminalDeviceInfo.put("device_ip", "139.207.19.246");
        dataMap.put("terminal_device_info", terminalDeviceInfo);
        // 风控信息
        Map<String, String> riskMngInfo = new HashMap<>();
        riskMngInfo.put("subTradeType", "4300");
        Map<String, Object> riskCheckInfo = new HashMap<>();
        riskCheckInfo.put("riskMngInfo", riskMngInfo);
        riskCheckInfo.put("ipAddr", "139.207.19.246");
        // 注意，风控信息为JSON字符串
        // dataMap.put("risk_check_info", JSON.toJSONString(riskCheckInfo));
        dataMap.put("risk_check_info", riskCheckInfo);
        // 异步通知地址
        dataMap.put("notify_url", "virgo://http://www.vclinker.com");
        // 微信用户子标识 微信JS支付此参数必传
        dataMap.put("sub_openid", "");
        // 买家的支付宝唯一用户号 支付宝JS支付，buyer_id必送
        dataMap.put("buyer_id", "");
        // 用户在云闪付APP上的标识号，用来提供给收款方， 并在收款方发起交易时回传给付款方。（银联JS支付必填）
        // 通过获取银联用户标识获取
        dataMap.put("user_id", "");
        // 持卡人确认付款时的IP地址，用于防钓鱼。（银联JS支付必填）
        dataMap.put("client_ip", "");
        // 交易有效期
        cl.add(Calendar.MINUTE, 2);
        dataMap.put("time_expire", sdf.format(cl.getTime()));
        // 指定支付方式 是否禁止用户使用信用卡支付。默认不禁用，若禁止请填1
        dataMap.put("limit_pay", "1");
        // 延时标志 1为延迟 0为不延迟
        dataMap.put("is_delay_acct", "0");
        // 传入分帐遇到优惠的处理规则 1-按比例分 2-按顺序保障 3-只给交易商户
        dataMap.put("term_div_coupon_type", "3");
        // 分账串
        JSONObject acctSplitBunch = new JSONObject();
        JSONArray acctInfos = new JSONArray();
        // 分账方1
        JSONObject acctInfo = new JSONObject();
        acctInfo.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        acctInfo.put("div_amt", "0.01");
        acctInfos.add(acctInfo);
        // 分账方2
        acctInfo = new JSONObject();
        acctInfo.put("huifu_id", DemoConstants.DIV_HUIFU_ID);
        acctInfo.put("div_amt", "0.01");
        acctInfos.add(acctInfo);
        acctSplitBunch.put("acct_infos", acctInfos);
        dataMap.put("acct_split_bunch", acctSplitBunch);
        // 商户私有域
        dataMap.put("mer_priv", "");
        // 微信扩展参数集合
        dataMap.put("wx_data", "");
        // 支付宝扩展参数集合
        dataMap.put("alipay_data", "");
        // 银联扩展参数集合
        dataMap.put("unionpay_data", "");
        // 手续费类型 01:标准费率线上,02:标准费率线下,03:非盈利费率,04:缴费费率,05:保险费率,06:行业活动费率,07:校园餐饮费率,08:K12中小幼费率
        // 不送时取业务入驻配置的默认费率
        dataMap.put("pay_scene", "02");
        // 分期贴息类型，1:商户贴息，默认商户不贴息。注意：当此处填1时，花呗商户承担比例hb_fq_seller_percent只能填0
        dataMap.put("fq_mer_discount_flag", 0);
        // 交易备注
        dataMap.put("remark", "");

        Map<String, Object> pullPayInfo = new HashMap<>();
        try {
            System.out.println("聚合正扫请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            pullPayInfo = BasePayClient.request(dataMap, "top.trans.pullPayInfo");
            // 多商户模式需指定merchantKey
            // pullPayInfo = BasePayClient.request(dataMap, "top.trans.pullPayInfo", "merchantKey1");
            System.out.println("聚合正扫返回参数：" + JSON.toJSONString(pullPayInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) pullPayInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("00000100".equals(subRespCode)) {
            // 聚合正扫返回处理中获取二维码
            String qrCode = (String) pullPayInfo.get("qr_code");
            System.out.println("qr_code :" + qrCode);
        } else {
            String subRespDesc = (String) pullPayInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 银联正扫Native支付
     */
    public static void executeUnionPayNative () {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 系统号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 商户订单号，需保证商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("mer_ord_id", nowStr + "1234567890");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 交易类型
        // 微信公众号-T_JSAPI 小程序-T_MINIAPP 支付宝JS-A_JSAPI 支付宝正扫-A_NATIVE 银联正扫-U_NATIVE 银联JS-U_JSAPI
        dataMap.put("trade_type", "U_NATIVE");
        // 交易金额
        dataMap.put("trans_amt", "0.02");
        // 商品描述
        dataMap.put("goods_desc", "测试商品");
        // 设备信息
        JSONObject terminalDeviceInfo = new JSONObject();
        terminalDeviceInfo.put("device_type", "4");
        terminalDeviceInfo.put("device_ip", "139.207.19.246");
        dataMap.put("terminal_device_info", terminalDeviceInfo);
        // 风控信息
        Map<String, String> riskMngInfo = new HashMap<>();
        riskMngInfo.put("subTradeType", "4300");
        Map<String, Object> riskCheckInfo = new HashMap<>();
        riskCheckInfo.put("riskMngInfo", riskMngInfo);
        riskCheckInfo.put("ipAddr", "139.207.19.246");
        // 注意，风控信息为JSON字符串
        // dataMap.put("risk_check_info", JSON.toJSONString(riskCheckInfo));
        dataMap.put("risk_check_info", riskCheckInfo);
        // 异步通知地址
        dataMap.put("notify_url", "virgo://http://www.vclinker.com");
        // 微信用户子标识 微信JS支付此参数必传
        dataMap.put("sub_openid", "");
        // 买家的支付宝唯一用户号 支付宝JS支付，buyer_id必送
        dataMap.put("buyer_id", "");
        // 用户在云闪付APP上的标识号，用来提供给收款方， 并在收款方发起交易时回传给付款方。（银联JS支付必填）
        // 通过获取银联用户标识获取
        dataMap.put("user_id", "");
        // 持卡人确认付款时的IP地址，用于防钓鱼。（银联JS支付必填）
        dataMap.put("client_ip", "");
        // 交易有效期
        cl.add(Calendar.MINUTE, 2);
        dataMap.put("time_expire", sdf.format(cl.getTime()));
        // 指定支付方式 是否禁止用户使用信用卡支付。默认不禁用，若禁止请填1
        dataMap.put("limit_pay", "1");
        // 延时标志 1为延迟 0为不延迟
        dataMap.put("is_delay_acct", "0");
        // 传入分帐遇到优惠的处理规则 1-按比例分 2-按顺序保障 3-只给交易商户
        dataMap.put("term_div_coupon_type", "3");
        // 分账串
        JSONObject acctSplitBunch = new JSONObject();
        JSONArray acctInfos = new JSONArray();
        // 分账方1
        JSONObject acctInfo = new JSONObject();
        acctInfo.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        acctInfo.put("div_amt", "0.01");
        acctInfos.add(acctInfo);
        // 分账方2
        acctInfo = new JSONObject();
        acctInfo.put("huifu_id", DemoConstants.DIV_HUIFU_ID);
        acctInfo.put("div_amt", "0.01");
        acctInfos.add(acctInfo);
        acctSplitBunch.put("acct_infos", acctInfos);
        dataMap.put("acct_split_bunch", acctSplitBunch);
        // 商户私有域
        dataMap.put("mer_priv", "");
        // 微信扩展参数集合
        dataMap.put("wx_data", "");
        // 支付宝扩展参数集合
        dataMap.put("alipay_data", "");
        // 银联扩展参数集合
        dataMap.put("unionpay_data", "");
        // 手续费类型 01:标准费率线上,02:标准费率线下,03:非盈利费率,04:缴费费率,05:保险费率,06:行业活动费率,07:校园餐饮费率,08:K12中小幼费率
        // 不送时取业务入驻配置的默认费率
        dataMap.put("pay_scene", "02");
        // 分期贴息类型，1:商户贴息，默认商户不贴息。注意：当此处填1时，花呗商户承担比例hb_fq_seller_percent只能填0
        dataMap.put("fq_mer_discount_flag", 0);
        // 交易备注
        dataMap.put("remark", "");

        Map<String, Object> pullPayInfo = new HashMap<>();
        try {
            System.out.println("聚合正扫请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            pullPayInfo = BasePayClient.request(dataMap, "top.trans.pullPayInfo");
            // 多商户模式需指定merchantKey
            // pullPayInfo = BasePayClient.request(dataMap, "top.trans.pullPayInfo", "merchantKey1");
            System.out.println("聚合正扫返回参数：" + JSON.toJSONString(pullPayInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) pullPayInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("00000100".equals(subRespCode)) {
            // 聚合正扫返回处理中获取二维码
            String qrCode = (String) pullPayInfo.get("qr_code");
            System.out.println("qr_code :" + qrCode);
        } else {
            String subRespDesc = (String) pullPayInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 聚合反扫调用实例
     */
    public static void executeAuthCodePay () {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());

        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 系统编号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 商户订单号，需保证商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("mer_ord_id", nowStr + "1234567890");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 渠道号，若需使用自有渠道请联系业务对接人
        dataMap.put("bank_channel_no", "");
        // 交易金额
        dataMap.put("trans_amt", "0.02");
        // 商品描述
        dataMap.put("goods_desc", "测试商品");
        // 支付授权码,本接口会自动识别微信、支付宝、银联二维码
        // dataMap.put("auth_code", DemoConstants.ALIPAY_AUTH_CODE);
        dataMap.put("auth_code", DemoConstants.WX_AUTH_CODE);
        // dataMap.put("auth_code", DemoConstants.UNIONPAY_AUTH_CODE);
        // 风控信息
        Map<String, String> riskMngInfo = new HashMap<>();
        riskMngInfo.put("subTradeType", "4300");
        Map<String, Object> riskCheckInfo = new HashMap<>();
        riskCheckInfo.put("riskMngInfo", riskMngInfo);
        riskCheckInfo.put("ipAddr", "139.207.19.246");
        // 注意，风控信息为JSON字符串
        // dataMap.put("risk_check_info", JSON.toJSONString(riskCheckInfo));
        dataMap.put("risk_check_info", riskCheckInfo);
        // 设备信息
        JSONObject terminalDeviceInfo = new JSONObject();
        terminalDeviceInfo.put("device_type", "4");
        terminalDeviceInfo.put("device_ip", "139.207.19.246");
        dataMap.put("terminal_device_info", terminalDeviceInfo);
        // 异步通知地址
        dataMap.put("notify_url", "virgo://http://www.vclinker.com");
        // 交易有效期
        cl.add(Calendar.MINUTE, 2);
        dataMap.put("time_expire", sdf.format(cl.getTime()));
        // 是否禁止用户使用信用卡支付。默认不禁用，若禁止请填1
        dataMap.put("limit_pay", "0");
        // 是否延时交易,1为延迟 0为不延迟
        dataMap.put("is_delay_acct", "0");
        // 传入分帐遇到优惠的处理规则 1-按比例分 2-按顺序保障 3-只给交易商户
        dataMap.put("term_div_coupon_type", "3");
        // 分账串，无需实时分账时可不传
        JSONObject acctSplitBunch = new JSONObject();
        JSONArray acctInfos = new JSONArray();
        // 分账方1
        JSONObject acctInfo = new JSONObject();
        acctInfo.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        acctInfo.put("div_amt", "0.01");
        acctInfos.add(acctInfo);
        // 分账方2
        acctInfo = new JSONObject();
        acctInfo.put("huifu_id", DemoConstants.DIV_HUIFU_ID);
        acctInfo.put("div_amt", "0.01");
        acctInfos.add(acctInfo);
        acctSplitBunch.put("acct_infos", acctInfos);
        dataMap.put("acct_split_bunch", acctSplitBunch);
        // 商户私有域
        dataMap.put("mer_priv", "");
        // 微信扩展参数集合
        dataMap.put("wx_data", "");
        // 支付宝扩展参数集合
        dataMap.put("alipay_data", "");
        // 银联扩展参数集合
        dataMap.put("unionpay_data", "");
        // 商户私有域
        dataMap.put("mer_priv", "");
        // 手续费类型 01:标准费率线上,02:标准费率线下,03:非盈利费率,04:缴费费率,05:保险费率,06:行业活动费率,07:校园餐饮费率,08:K12中小幼费率
        // 不送时取业务入驻配置的默认费率
        dataMap.put("pay_scene", "02");

        Map<String, Object> pullPayInfo = new HashMap<>();
        try {
            System.out.println("聚合反扫请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            pullPayInfo = BasePayClient.request(dataMap, "top.trans.authCodePay");
            // 多商户模式需指定merchantKey
            // pullPayInfo = BasePayClient.request(dataMap, "top.trans.authCodePay", "merchantKey1");
            System.out.println("聚合反扫返回参数：" + JSON.toJSONString(pullPayInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) pullPayInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("00000100".equals(subRespCode)) {
            // 聚合反扫返回处理中，等待异步通知结果
            // 前台如需要交易结果展示可调用交易查询来获取后续交易状态
        } else {
            String subRespDesc = (String) pullPayInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 扫码交易查询调用实例
     *
     * @see TransQueryDemo#executeQuery()
     */
    public static void executeQuery() {
        // 查询接口详见{@link TransQueryDemo#executeQuery}
        TransQueryDemo.executeQuery();
    }

    /**
     * 扫码交易退款调用实例
     *
     * @see TransRefundDemo#executeRefund()
     */
    public static void executeRefund() {
        // 查询接口详见{@link TransRefundDemo#executeRefund}
        TransRefundDemo.executeRefund();
    }

    /**
     * 扫码交易退款查询调用实例
     *
     * @see TransRefundDemo#executeRefundQuery()
     */
    public static void executeRefundQuery() {
        // 查询接口详见{@link TransQueryDemo#executeRefundQuery}
        TransRefundDemo.executeRefundQuery();
    }

    /**
     * 扫码关单接口调用实例
     */
    public static void executeClose() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());

        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 系统编号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 原交易请求流水号
        dataMap.put("org_req_seq_id", "2021042116561701234567890");
        // 原交易请求日期
        dataMap.put("org_req_date", "20210421");

        Map<String, Object> closeResult = new HashMap<>();
        try {
            System.out.println("扫码关单请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            closeResult = BasePayClient.request(dataMap, "toprrc.close");
            // 多商户模式需指定merchantKey
            // closeResult = BasePayClient.request(dataMap, "toprrc.close", "merchantKey1");
            System.out.println("扫码关单返回参数：" + JSON.toJSONString(closeResult));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) closeResult.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
            // 获取关单状态
            String stat = (String)closeResult.get("trans_stat");
            // 判断是否关单成功
            if ("S".equals(stat)) {
                // 获取原交易状态
                String orgTransStat = (String) closeResult.get("org_trans_stat");
                // 原交易状态只是参考，推荐关单成功后调用交易查询接口查询交易状态
            }
        } else {
            String subRespDesc = (String) closeResult.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 获取银联用户标识调用实例
     */
    public static void executeGetUnionpayUserId () {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());

        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 系统编号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 银联用户授权码
        dataMap.put("user_auth_code", DemoConstants.UNIONPAY_USER_AUTH_CODE);
        // APP标识，不传默认CloudPay
        dataMap.put("app_up_identifier", "CloudPay");

        Map<String, Object> unionPayUserInfo = new HashMap<>();
        try {
            System.out.println("获取银联用户标识请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            unionPayUserInfo = BasePayClient.request(dataMap, "top.trans.getUserMark");
            // 多商户模式需指定merchantKey
            // unionPayUserInfo = BasePayClient.request(dataMap, "top.trans.getUserMark", "merchantKey1");
            System.out.println("获取银联用户标识返回参数：" + JSON.toJSONString(unionPayUserInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) unionPayUserInfo.get("sub_resp_code");
        // 获取银联用户标识接口业务返回码000代表成功
        if ("000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
            // 获取返回的银联用户标识
            String userId = (String)unionPayUserInfo.get("user_id");
            System.out.println("获取到的银联用户标识：" + userId);
        } else {
            String subRespDesc = (String) unionPayUserInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }
}