package com.huifu.bspay.sdk.demo.trans;

import java.net.URLEncoder;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.alibaba.fastjson.JSON;
import com.huifu.bspay.sdk.client.BasePayClient;
import com.huifu.bspay.sdk.demo.constants.DemoConstants;
import com.huifu.bspay.sdk.core.exception.BasePayException;

/**
 * 银行卡分期业务调用实例
 * 
 * @author shuaifeng.zhao
 * @version v 0.1
 */
public class BankInstallmentDemo {

    /**
     * 银行卡分期签约调用实例
     * 
     */
    public static void executeSign() {
        
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id",  nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 系统号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);

        // 银行编号
        dataMap.put("bank_no", DemoConstants.BANK_NO);
        // 持卡人姓名
        dataMap.put("card_name", DemoConstants.CARD_NAME);
        // 银行卡号
        dataMap.put("card_no", DemoConstants.CARD_NO);
        // 银行卡手机号
        dataMap.put("card_mobile", DemoConstants.CARD_MOBILE);
        // 证件类型  01：身份证
        dataMap.put("id_type", "01");
        // 证件号
        dataMap.put("id_no", DemoConstants.ID_NO);
        // CVV2
        dataMap.put("cvv2", DemoConstants.CVV2);
        // 有效期
        dataMap.put("valid_date", DemoConstants.VALID_DATE);
        // 卡类型 D:借记卡 C:信用卡 P:存折 Y:预付费卡 V:虚拟账户 Z:借贷合一卡
        dataMap.put("card_type", DemoConstants.CARD_TYPE);
        // 银行账户类型 E：对公，P：对私
        dataMap.put("card_acct_type", "P");
        // 交易金额 单位元，需保留小数点后两位
        dataMap.put("trans_amt", DemoConstants.TRANS_AMT);
        // 订单有效期即订单失效时间
//        dataMap.put("time_expire", nowStr);
        
        Map<String, Object> deviceInfo = new HashMap<>();
        // 设备类型 1:手机2:平板3:手表4:PC
        deviceInfo.put("device_type", "4");
        // 交易设备IP(公网IP,目前暂传IPv4格式)
        deviceInfo.put("device_ip", "172.31.18.64");
        // 交易设备MAC
        deviceInfo.put("device_mac", "");
        // 交易设备GPS
        deviceInfo.put("device_gps", "");
        // 交易设备IMEI
        deviceInfo.put("device_imei", "");
        // 交易设备IMSI
        deviceInfo.put("device_imsi", "");
        // 交易设备ICCID
        deviceInfo.put("device_icc_id", "");
        // 交易设备WIFIMAC
        deviceInfo.put("device_wifi_mac", "");
        // 逻辑终端号(汇付机具必传)
        deviceInfo.put("pnr_dev_id", "");
        // 汇付机具号(汇付机具必传)
        deviceInfo.put("devs_id", "");
        //
        dataMap.put("terminal_device_info", deviceInfo);
        // 异步通知地址
        dataMap.put("notify_url", "virgo://http://www.vclinker.com");
        // 页面跳转地址(支付成功后，前端跳转地址)
        dataMap.put("business_url", "http://www.baidu.com");
        // 请求类型 0:pc 1:安卓 2：ios
        dataMap.put("request_type", "0");
        // 业务地址 6位地区编码
        dataMap.put("place_id", "200000");
        
        Map<String, Object> transInfo = new HashMap<>();
        try {
            System.out.println("银行卡分期签约请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            transInfo = BasePayClient.request(dataMap, "top.bccredit.sign");
            // 多商户模式需指定merchantKey
            // transInfo = BasePayClient.request(dataMap, "top.bccredit.sign", "merchantKey1");
            System.out.println("银行卡分期签约返回参数：" + JSON.toJSONString(transInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) transInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("00000100".equals(subRespCode)) {
            // 取现交易返回处理中
            String reqSeqId = (String) transInfo.get("req_seq_id");
            String merOrdId = (String) transInfo.get("mer_ord_id");
            System.out.println("reqSeqId :" + reqSeqId + ", merOrdId:" + merOrdId);
        } else {
            String subRespDesc = (String) transInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }
    

    /**
     * 银行卡分期支付调用实例
     * 
     */
    public static void executePayment() {
        
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id",  nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 系统号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);

        // 商户订单号
        dataMap.put("mer_ord_id", nowStr + "01234");
        
        // 银行编号
        dataMap.put("bank_no", DemoConstants.BANK_NO);
        // 持卡人姓名
        dataMap.put("card_name", DemoConstants.CARD_NAME);
        // 银行卡号
        dataMap.put("card_no", DemoConstants.CARD_NO);
        // 银行卡手机号
        dataMap.put("card_mobile", DemoConstants.CARD_MOBILE);
        // 证件类型  01：身份证
        dataMap.put("id_type", "01");
        // 证件号
        dataMap.put("id_no", DemoConstants.ID_NO);
        // CVV2
        dataMap.put("cvv2", DemoConstants.CVV2);
        // 有效期
        dataMap.put("valid_date", DemoConstants.VALID_DATE);
        // 卡类型 D:借记卡 C:信用卡 P:存折 Y:预付费卡 V:虚拟账户 Z:借贷合一卡
        dataMap.put("card_type", DemoConstants.CARD_TYPE);
        // 银行账户类型 E：对公，P：对私
        dataMap.put("card_acct_type", "P");
        // 交易金额 单位元，需保留小数点后两位
        dataMap.put("trans_amt", DemoConstants.TRANS_AMT);
        // 手续费收取方式 1-实收 2-后收
        dataMap.put("fee_rec_type", "2");
        
        Map<String, Object> extendInfo = new HashMap<>();
        // 付款终端类型 01：电脑02：手机03：平板设备04：可穿戴设备05：数字电视06：条码支付受理终端99：其他
        extendInfo.put("pyer_trx_trm_tp", "99");
        // 付款终端编码 标识交易终端的唯一、固定的编码。应符合《网络支付报文结构及要素技术规范（V1.0）》（银办发〔2016〕222号）要求，最长为32个字符
        extendInfo.put("pyer_trx_trm_no", "");
        // 收款方账户编号 网联银联支付使用
        extendInfo.put("pyee_acct_id", "6214***************6688");
        // 收款方账户名称
        extendInfo.put("pyee_nm", "李四");
        // 收款方账户类型 （见数据字典的收款方账户类型, 默认值：04 单位支付账户）
        extendInfo.put("pyee_acct_tp", "04");
        // 收款终端类型：01：电脑02：手机03：平板设备04：可穿戴设备05：数字电视06：条码支付受理终端99：其他
        extendInfo.put("pyee_trx_trm_tp", "99");
        // 收款终端编码：标识交易终端的唯一、固定的编码。应符合《网络支付报文结构及要素技术规范（V1.0）》（银办发〔2016〕222号）要求，最长为32个字符。
        extendInfo.put("pyee_trx_trm_no", "");
        // 二级商户类型： 01：法人02：其他组织03：个体工商户04：自然人
        extendInfo.put("mer_type", "02");
        // 二级商户证件类型：00：身份证01：护照02：军官证03：军官证04：回乡证05：户口簿06：警官证07：临时身份证08：台胞证09：港澳通行证10：企业营业执照11：法人代表证12：外国人永久居留证，即绿卡13：其他
        extendInfo.put("mer_id_type", "00");
        // 二级商户证件编码
        extendInfo.put("mer_id_no", "310528198006088686");
        // 二级商户行业类别 参照银联MCC编码
        extendInfo.put("mer_cat_code", "8541");
        // 商品简称
        extendInfo.put("goods_short_name", "*********");
        // 业务种类 参见附录 业务种类
        extendInfo.put("biz_tp", "100001");
        
        
        // 网联扩展字段 json String
        dataMap.put("extend_pay", extendInfo);
        // 订单有效期即订单失效时间
        dataMap.put("time_expire", nowStr);
        
        Map<String, Object> deviceInfo = new HashMap<>();
        // 设备类型 1:手机2:平板3:手表4:PC
        deviceInfo.put("device_type", "4");
        // 交易设备IP(公网IP,目前暂传IPv4格式)
        deviceInfo.put("device_ip", "10.10.0.1");
        // 交易设备MAC
        deviceInfo.put("device_mac", "");
        // 交易设备GPS
        deviceInfo.put("device_gps", "");
        // 交易设备IMEI
        deviceInfo.put("device_imei", "");
        // 交易设备IMSI
        deviceInfo.put("device_imsi", "");
        // 交易设备ICCID
        deviceInfo.put("device_icc_id", "");
        // 交易设备WIFIMAC
        deviceInfo.put("device_wifi_mac", "");
        // 逻辑终端号(汇付机具必传)
        deviceInfo.put("pnr_dev_id", "");
        // 汇付机具号(汇付机具必传)
        deviceInfo.put("devs_id", "");
        // 设备信息 Json对象
        dataMap.put("terminal_device_info", deviceInfo);
        
        // 风控信息
        Map<String, Object> riskCheckInfo = new HashMap<String, Object>();
        // 经度
        riskCheckInfo.put("longitude", "");
        // 纬度
        riskCheckInfo.put("latitude", "");
        // 基站地址
        riskCheckInfo.put("base_station", "");
        
        // 风控信息 json String
        dataMap.put("risk_check_info",  JSON.toJSONString(riskCheckInfo));
        
        // 异步通知地址
        dataMap.put("notify_url", "virgo://http://www.vclinker.com");
        // 分期期数 03 06 12 24
        dataMap.put("instalments_num", "3");
        // 延时标记 1为延迟 0为不延迟
        dataMap.put("is_delay_acct", "0");
        
        Map<String, Object> accInfo1 = new HashMap<String, Object>();
        // 子客户号
        accInfo1.put("huifu_id", "6666000104218017");
        // 分账金额
        accInfo1.put("div_amt", "88888");
        
        Map<String, Object> accInfo2 = new HashMap<String, Object>();
        // 子客户号
        accInfo2.put("huifu_id", "6666000104218018");
        // 分账金额
        accInfo2.put("div_amt", "0.88");
        
        List<Map<String, Object>> accInfoList = new ArrayList<Map<String,Object>>();
        accInfoList.add(accInfo1);
        accInfoList.add(accInfo2);
        
        Map<String, Object> accBuchInfo = new HashMap<String, Object>();
        accBuchInfo.put("acct_infos", accInfoList);
        
        // 分账串
//        dataMap.put("acct_split_bunch", accBuchInfo);
        
        Map<String, Object> transInfo = new HashMap<>();
        try {
            System.out.println("银行卡分期支付请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            transInfo = BasePayClient.request(dataMap, "top.bccredit.paymentApply");
            // 多商户模式需指定merchantKey
            // transInfo = BasePayClient.request(dataMap, "top.bccredit.paymentApply", "merchantKey1");
            System.out.println("银行卡分期支付返回参数：" + JSON.toJSONString(transInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) transInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("00000100".equals(subRespCode)) {
            // 取现交易返回处理中
            String reqSeqId = (String) transInfo.get("req_seq_id");
            String merOrdId = (String) transInfo.get("mer_ord_id");
            System.out.println("reqSeqId :" + reqSeqId + ", merOrdId:" + merOrdId);
        } else {
            String subRespDesc = (String) transInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }
    
    /**
     * 银行卡分期支付查询调用实例
     */
    public static void executePaymentQuery() {
        
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 原始请求日期，指原交易的请求日期
        dataMap.put("req_date", "20210423");
        // 系统号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 以下指定原交易的唯一标识，支持5选1，可根据req_seq_id、party_order_id、out_trans_id、out_ord_id、hf_seq_id其中之一定位原交易
        // 原始请求流水号
        dataMap.put("req_seq_id", "2021042313333801234567890");

        Map<String, Object> transInfo = new HashMap<>();
        try {
            System.out.println("交易查询请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            transInfo = BasePayClient.request(dataMap, "topqur.bcCreditPayQuery");
            // 多商户模式需指定merchantKey
            // transInfo = BasePayClient.request(dataMap, "topqur.bcCreditPayQuery", "merchantKey1");
            System.out.println("交易查询返回参数：" + JSON.toJSONString(transInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) transInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 查询成功
            System.out.println("查询成功");
            // 获取原交易的状态
            String transStat = (String)transInfo.get("trans_stat");
            System.out.println("交易状态trans_stat=" + transStat);
        } else {
            String subRespDesc = (String) transInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }
    
    

    /**
     * 银行卡分期支付确认调用实例
     * 
     */
    public static void executePaymentConfirm() {
        
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id",  nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 系统号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 商户订单号（即商户支付订单号，与支付申请订单号保持一致）
        dataMap.put("mer_ord_id", nowStr + "01234");
        // 原请求流水号
        dataMap.put("org_seq_id", "2021042313324401234567890");
        // 原请求时间
        dataMap.put("org_seq_date", "20210423");
        
        // CVV2
        dataMap.put("cvv2", DemoConstants.CVV2);
        // 有效期
        dataMap.put("valid_date", DemoConstants.VALID_DATE);
        // 手机验证码
        dataMap.put("verify_code", "906046");
        
        Map<String, Object> extendInfo = new HashMap<>();
        // 付款终端类型 01：电脑02：手机03：平板设备04：可穿戴设备05：数字电视06：条码支付受理终端99：其他
        extendInfo.put("pyer_trx_trm_tp", "99");
        // 付款终端编码 标识交易终端的唯一、固定的编码。应符合《网络支付报文结构及要素技术规范（V1.0）》（银办发〔2016〕222号）要求，最长为32个字符
        extendInfo.put("pyer_trx_trm_no", "");
        // 收款方账户编号 网联银联支付使用
        extendInfo.put("pyee_acct_id", "6214***************6688");
        // 收款方账户名称
        extendInfo.put("pyee_nm", "李四");
        // 收款方账户类型 （见数据字典的收款方账户类型, 默认值：04 单位支付账户）
        extendInfo.put("pyee_acct_tp", "04");
        // 收款终端类型：01：电脑02：手机03：平板设备04：可穿戴设备05：数字电视06：条码支付受理终端99：其他
        extendInfo.put("pyee_trx_trm_tp", "99");
        // 收款终端编码：标识交易终端的唯一、固定的编码。应符合《网络支付报文结构及要素技术规范（V1.0）》（银办发〔2016〕222号）要求，最长为32个字符。
        extendInfo.put("pyee_trx_trm_no", "");
        // 二级商户类型： 01：法人02：其他组织03：个体工商户04：自然人
        extendInfo.put("mer_type", "02");
        // 二级商户证件类型：00：身份证01：护照02：军官证03：军官证04：回乡证05：户口簿06：警官证07：临时身份证08：台胞证09：港澳通行证10：企业营业执照11：法人代表证12：外国人永久居留证，即绿卡13：其他
        extendInfo.put("mer_id_type", "00");
        // 二级商户证件编码
        extendInfo.put("mer_id_no", "310528198006088686");
        // 二级商户行业类别 参照银联MCC编码
        extendInfo.put("mer_cat_code", "8541");
        // 商品简称
        extendInfo.put("goods_short_name", "*********");
        // 业务种类 参见附录 业务种类
        extendInfo.put("biz_tp", "100001");
        
        
        // 网联扩展字段 json String
        dataMap.put("extend_pay", extendInfo);
        // 订单有效期即订单失效时间
        dataMap.put("time_expire", nowStr);
        
        Map<String, Object> deviceInfo = new HashMap<>();
        // 设备类型 1:手机2:平板3:手表4:PC
        deviceInfo.put("device_type", "4");
        // 交易设备IP(公网IP,目前暂传IPv4格式)
        deviceInfo.put("device_ip", "10.10.0.1");
        // 交易设备MAC
        deviceInfo.put("device_mac", "");
        // 交易设备GPS
        deviceInfo.put("device_gps", "");
        // 交易设备IMEI
        deviceInfo.put("device_imei", "");
        // 交易设备IMSI
        deviceInfo.put("device_imsi", "");
        // 交易设备ICCID
        deviceInfo.put("device_icc_id", "");
        // 交易设备WIFIMAC
        deviceInfo.put("device_wifi_mac", "");
        // 逻辑终端号(汇付机具必传)
        deviceInfo.put("pnr_dev_id", "");
        // 汇付机具号(汇付机具必传)
        deviceInfo.put("devs_id", "");
        // 设备信息 Json对象
        dataMap.put("terminal_device_info", deviceInfo);
        
        // 风控信息
        Map<String, Object> riskCheckInfo = new HashMap<String, Object>();
        // 经度
        riskCheckInfo.put("longitude", "");
        // 纬度
        riskCheckInfo.put("latitude", "");
        // 基站地址
        riskCheckInfo.put("base_station", "");
        
        // 风控信息 json String
        dataMap.put("risk_check_info",  JSON.toJSONString(riskCheckInfo));
        
        // 异步通知地址
        dataMap.put("notify_url", "virgo://http://www.vclinker.com");
        
        Map<String, Object> transInfo = new HashMap<>();
        try {
            System.out.println("银行卡分期支付确认请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            transInfo = BasePayClient.request(dataMap, "top.bccredit.paymentConfirm");
            // 多商户模式需指定merchantKey
            // transInfo = BasePayClient.request(dataMap, "top.bccredit.paymentConfirm", "merchantKey1");
            System.out.println("银行卡分期支付确认返回参数：" + JSON.toJSONString(transInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) transInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("00000100".equals(subRespCode)) {
            // 取现交易返回处理中
            String reqSeqId = (String) transInfo.get("req_seq_id");
            String merOrdId = (String) transInfo.get("mer_ord_id");
            System.out.println("reqSeqId :" + reqSeqId + ", merOrdId:" + merOrdId);
        } else {
            String subRespDesc = (String) transInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }
    

    /**
     * 银行卡分期支付退款调用实例
     * 
     */
    public static void executeRefund() {
        
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id",  nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 系统号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 商户订单号
        dataMap.put("mer_ord_id", nowStr + "01234");
        // 退款金额
        dataMap.put("ord_amt", "100.00");
        // 原交易请求流水号 org_req_seq_id,party_order_id,hf_seq_id必须传一个
        dataMap.put("org_req_seq_id", "2021042313333801234567890");
//        // 原交易的支付凭证号 org_req_seq_id,party_order_id,hf_seq_id必须传一个
//        dataMap.put("party_order_id", "202003021008068888888966855645");
//        // 原交易全局流水号 org_req_seq_id,party_order_id,hf_seq_id必须传一个
//        dataMap.put("hf_seq_id", "20200302100806568788");
        // 原交易请求日期
        dataMap.put("org_req_date", "20210423");
        

        Map<String, Object> accInfo1 = new HashMap<String, Object>();
        // 子客户号
        accInfo1.put("huifu_id", "6666000104218017");
        // 分账金额
        accInfo1.put("div_amt", "88888");
        
        Map<String, Object> accInfo2 = new HashMap<String, Object>();
        // 子客户号
        accInfo2.put("huifu_id", "6666000104218018");
        // 分账金额
        accInfo2.put("div_amt", "0.88");
        
        List<Map<String, Object>> accInfoList = new ArrayList<Map<String,Object>>();
        accInfoList.add(accInfo1);
        accInfoList.add(accInfo2);
        
        Map<String, Object> accBuchInfo = new HashMap<String, Object>();
        accBuchInfo.put("acct_infos", accInfoList);
        
        // 分账串
//        dataMap.put("acct_split_bunch", accBuchInfo);
        
        Map<String, Object> deviceInfo = new HashMap<>();
        // 设备类型 1:手机2:平板3:手表4:PC
        deviceInfo.put("device_type", "4");
        // 交易设备IP(公网IP,目前暂传IPv4格式)
        deviceInfo.put("device_ip", "10.10.0.1");
        // 交易设备MAC
        deviceInfo.put("device_mac", "");
        // 交易设备GPS
        deviceInfo.put("device_gps", "");
        // 交易设备IMEI
        deviceInfo.put("device_imei", "");
        // 交易设备IMSI
        deviceInfo.put("device_imsi", "");
        // 交易设备ICCID
        deviceInfo.put("device_icc_id", "");
        // 交易设备WIFIMAC
        deviceInfo.put("device_wifi_mac", "");
        // 逻辑终端号(汇付机具必传)
        deviceInfo.put("pnr_dev_id", "");
        // 汇付机具号(汇付机具必传)
        deviceInfo.put("devs_id", "");
        // 设备信息 Json对象
        dataMap.put("terminal_device_info", deviceInfo);
        
        // 风控信息
        Map<String, Object> riskCheckInfo = new HashMap<String, Object>();
        // 经度
        riskCheckInfo.put("longitude", "");
        // 纬度
        riskCheckInfo.put("latitude", "");
        // 基站地址
        riskCheckInfo.put("base_station", "");
        
        // 风控信息 json String
        dataMap.put("risk_check_info",  JSON.toJSONString(riskCheckInfo));
        
        // 退货原因，超出长度会导致退货失败，UrlEncode进行编码，如：%E6%B5%8B%E8%AF
        dataMap.put("mark", URLEncoder.encode("退货原因"));
        // 异步通知地址
        dataMap.put("notify_url", "virgo://http://www.vclinker.com");
        
        Map<String, Object> transInfo = new HashMap<>();
        try {
            System.out.println("银行卡分期支付退款请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            transInfo = BasePayClient.request(dataMap, "toprrc.bccredit.refund");
            // 多商户模式需指定merchantKey
            // transInfo = BasePayClient.request(dataMap, "toprrc.bccredit.refund", "merchantKey1");
            System.out.println("银行卡分期支付退款返回参数：" + JSON.toJSONString(transInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) transInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("00000100".equals(subRespCode)) {
            // 取现交易返回处理中
            String reqSeqId = (String) transInfo.get("req_seq_id");
            String merOrdId = (String) transInfo.get("mer_ord_id");
            System.out.println("reqSeqId :" + reqSeqId + ", merOrdId:" + merOrdId);
        } else {
            String subRespDesc = (String) transInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }
    
    /**
     * 银行卡分期支付退款查询调用实例
     *
     * <p>
     *     当一笔退款返回处理中或者通信超时状态未明时调用退款查询接口获取退款详细
     * </p>
     *
     */
    public static void executeRefundQuery(){
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 原退款请求日期
        dataMap.put("req_date", "20210423");
        // 汇付分配系统号
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 以下上送原退款的唯一标识、mer_ord_id、req_seq_id、hf_seq_id、out_ord_id可4选1
        // 原退款请求流水号
        dataMap.put("req_seq_id", nowStr + "01234567890");

        Map<String, Object> refundInfo = new HashMap<>();
        try {
            System.out.println("交易退款查询请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            refundInfo = BasePayClient.request(dataMap, "toprrc.refund");
            // 多商户模式需指定merchantKey
            // refundInfo = BasePayClient.request(dataMap, "toprrc.refund", "merchantKey1");
            System.out.println("交易退款查询返回参数：" + JSON.toJSONString(refundInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) refundInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 查询处理成功
            String transStat = (String) refundInfo.get("trans_stat");
            System.out.println("查询成功, 交易结果为：" + transStat);
        } else {
            String subRespDesc = (String) refundInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }

    }
    
    /**
     * 银行卡分期支付延时交易确认接口
     * 对一笔延时交易进行交易确认，资金分配由传入的分账串进行指定
     */
    public static void executePayDelayConfirm() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", "20210412");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 系统号
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 商户订单号
        dataMap.put("mer_ord_id", (String)dataMap.get("req_date") + dataMap.get("req_seq_id"));
        // 原交易请求流水号
        dataMap.put("org_req_seq_id", "123456");
        // 原交易请求日期
        dataMap.put("org_req_date", "20210414");

        // 分账串
        List<Map<String, String>> acctInfos = new ArrayList<>();
        Map<String, String> acctInfo1 = new HashMap<>();
        // 分账商户号1
        acctInfo1.put("huifu_id", DemoConstants.DIV_HUIFU_ID);
        // 分账金额1
        acctInfo1.put("div_amt", "1.00");
        acctInfos.add(acctInfo1);
        Map<String, Object> acctSplitBunch = new HashMap<>();
        acctSplitBunch.put("acct_infos", acctInfos);
        dataMap.put("acct_split_bunch", acctSplitBunch);

        Map<String, Object> payConfirm = new HashMap<>();
        try {
            System.out.println("交易确认请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            payConfirm = BasePayClient.request(dataMap, "topat.payConfirm");
            // 多商户模式需指定merchantKey
            // payConfirm = BasePayClient.request(dataMap, "topat.payConfirm", "merchantKey1");
            System.out.println("交易确认返回参数：" + JSON.toJSONString(payConfirm));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) payConfirm.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) payConfirm.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 银行卡分期支付交易确认查询接口
     * 对确认结果未知的延时确认交易发起查询
     */
    public static void executePayDelayConfirmQuery() {
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 交易确认请求流水号
        dataMap.put("req_seq_id", "01234567890");
        // 交易确认请求日期
        dataMap.put("req_date", "20210412");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 系统号
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);

        Map<String, Object> payConfirmInfo = new HashMap<>();
        try {
            System.out.println("交易确认查询请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            payConfirmInfo = BasePayClient.request(dataMap, "topqur.payConfirmQuery");
            // 多商户模式需指定merchantKey
            // payConfirmInfo = BasePayClient.request(dataMap, "topqur.payConfirmQuery", "merchantKey1");
            System.out.println("交易确认查询返回参数：" + JSON.toJSONString(payConfirmInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) payConfirmInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) payConfirmInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 交易确认退款接口
     * 对一笔延时交易的交易确认进行撤销
     */
    public static void executePayDelayConfirmRefund() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", "20210412");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 系统号
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 商户订单号
        dataMap.put("mer_ord_id", (String)dataMap.get("req_date") + dataMap.get("req_seq_id"));
        // 原交易请求流水号
        dataMap.put("org_req_seq_id", "123456");
        // 原交易请求日期
        dataMap.put("org_req_date", "20210414");

        // 分账串
        List<Map<String, String>> acctInfos = new ArrayList<>();
        Map<String, String> acctInfo1 = new HashMap<>();
        // 分账商户号1
        acctInfo1.put("huifu_id", DemoConstants.DIV_HUIFU_ID);
        // 分账金额1
        acctInfo1.put("div_amt", "1.00");
        acctInfos.add(acctInfo1);
        Map<String, Object> acctSplitBunch = new HashMap<>();
        acctSplitBunch.put("acct_infos", acctInfos);
        dataMap.put("acct_split_bunch", acctSplitBunch);

        Map<String, Object> payConfirm = new HashMap<>();
        try {
            System.out.println("交易确认退款请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            payConfirm = BasePayClient.request(dataMap, "toprrc.payConfirmRefund");
            // 多商户模式需指定merchantKey
            // payConfirm = BasePayClient.request(dataMap, "toprrc.payConfirmRefund", "merchantKey1");
            System.out.println("交易确认退款返回参数：" + JSON.toJSONString(payConfirm));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) payConfirm.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) payConfirm.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 银行卡分期支付延时交易确认批量查询接口
     * 查询一笔正向交易下所有的交易确认信息
     */
    public static void executePayDelayConfirmListQuery() {
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 原交易请求流水号
        dataMap.put("trans_req_seq_id", "01234567890");
        // 原交易请求日期
        dataMap.put("trans_req_date", "20210412");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);

        Map<String, Object> payConfirmInfo = new HashMap<>();
        try {
            System.out.println("交易确认批量查询请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            payConfirmInfo = BasePayClient.request(dataMap, "topqur.payConfirmListQuery");
            // 多商户模式需指定merchantKey
            // payConfirmInfo = BasePayClient.request(dataMap, "topqur.payConfirmListQuery", "merchantKey1");
            System.out.println("交易确认批量查询返回参数：" + JSON.toJSONString(payConfirmInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) payConfirmInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) payConfirmInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }
    
}
