package com.huifu.bspay.sdk.demo.trans;

import com.alibaba.fastjson.JSON;
import com.huifu.bspay.sdk.client.BasePayClient;
import com.huifu.bspay.sdk.demo.constants.DemoConstants;
import com.huifu.bspay.sdk.core.exception.BasePayException;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @ClassName TradeConfirmDemo.java
 * @Description
 * @Author jili.hua
 * @Date 2021/4/14 11:19
 * @Version 1.0
 **/
public class TradeConfirmDemo {

    /**
     * 交易确认接口
     */
    public static void executePayConfirm() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", "20210422");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 系统号
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 商户订单号
        dataMap.put("mer_ord_id", (String)dataMap.get("req_date") + dataMap.get("req_seq_id"));
        // 原交易请求流水号
        dataMap.put("org_req_seq_id", "2021042214110401234567890");
        // 原交易请求日期
        dataMap.put("org_req_date", "20210422");

        // 分账串
        List<Map<String, String>> acctInfos = new ArrayList<>();
        Map<String, String> acctInfo1 = new HashMap<>();
        // 分账商户号1
        acctInfo1.put("huifu_id", DemoConstants.DIV_HUIFU_ID);
        // 分账金额1
        acctInfo1.put("div_amt", "0.01");
        acctInfos.add(acctInfo1);
        Map<String, Object> acctSplitBunch = new HashMap<>();
        acctSplitBunch.put("acct_infos", acctInfos);
        dataMap.put("acct_split_bunch", acctSplitBunch);

        Map<String, Object> payConfirm = new HashMap<>();
        try {
            System.out.println("交易确认请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            payConfirm = BasePayClient.request(dataMap, "topat.payConfirm");
            // 多商户模式需指定merchantKey
            // payConfirm = BasePayClient.request(dataMap, "topat.payConfirm", "merchantKey1");
            System.out.println("交易确认返回参数：" + JSON.toJSONString(payConfirm));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) payConfirm.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) payConfirm.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 交易确认查询接口
     */
    public static void executePayConfirmQuery() {
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 交易确认请求流水号
        dataMap.put("req_seq_id", "2021042214140301234567890");
        // 交易确认请求日期
        dataMap.put("req_date", "20210412");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 系统号
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);

        Map<String, Object> payConfirmInfo = new HashMap<>();
        try {
            System.out.println("交易确认查询请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            payConfirmInfo = BasePayClient.request(dataMap, "topqur.payConfirmQuery");
            // 多商户模式需指定merchantKey
            // payConfirmInfo = BasePayClient.request(dataMap, "topqur.payConfirmQuery", "merchantKey1");
            System.out.println("交易确认查询返回参数：" + JSON.toJSONString(payConfirmInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) payConfirmInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) payConfirmInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 交易确认退款接口
     */
    public static void executePayConfirmRefund() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", "20210422");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 系统号
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 商户订单号
        dataMap.put("mer_ord_id", (String)dataMap.get("req_date") + dataMap.get("req_seq_id"));
        // 原交易请求流水号
        dataMap.put("org_req_seq_id", "2021042214160701234567890");
        // 原交易请求日期
        dataMap.put("org_req_date", "20210422");

        // 分账串
        List<Map<String, String>> acctInfos = new ArrayList<>();
        Map<String, String> acctInfo1 = new HashMap<>();
        // 分账商户号1
        acctInfo1.put("huifu_id", DemoConstants.DIV_HUIFU_ID);
        // 分账金额1
        acctInfo1.put("div_amt", "0.01");
        acctInfos.add(acctInfo1);
        Map<String, Object> acctSplitBunch = new HashMap<>();
        acctSplitBunch.put("acct_infos", acctInfos);
        dataMap.put("acct_split_bunch", acctSplitBunch);

        Map<String, Object> payConfirm = new HashMap<>();
        try {
            System.out.println("交易确认退款请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            payConfirm = BasePayClient.request(dataMap, "toprrc.payConfirmRefund");
            // 多商户模式需指定merchantKey
            // payConfirm = BasePayClient.request(dataMap, "toprrc.payConfirmRefund", "merchantKey1");
            System.out.println("交易确认退款返回参数：" + JSON.toJSONString(payConfirm));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) payConfirm.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) payConfirm.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 交易确认批量查询接口
     */
    public static void executePayConfirmListQuery() {
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 原交易请求流水号
        dataMap.put("trans_req_seq_id", "2021042214110401234567890");
        // 原交易请求日期
        dataMap.put("trans_req_date", "20210422");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);

        Map<String, Object> payConfirmInfo = new HashMap<>();
        try {
            System.out.println("交易确认批量查询请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            payConfirmInfo = BasePayClient.request(dataMap, "topqur.payConfirmListQuery");
            // 多商户模式需指定merchantKey
            // payConfirmInfo = BasePayClient.request(dataMap, "topqur.payConfirmListQuery", "merchantKey1");
            System.out.println("交易确认批量查询返回参数：" + JSON.toJSONString(payConfirmInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) payConfirmInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) payConfirmInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }



}
