package com.huifu.bspay.sdk.demo.trans;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.HashMap;
import java.util.Map;

import com.alibaba.fastjson.JSON;
import com.huifu.bspay.sdk.client.BasePayClient;
import com.huifu.bspay.sdk.demo.constants.DemoConstants;
import com.huifu.bspay.sdk.core.exception.BasePayException;

/**
 * 取现业务调用实例
 * 
 * @author shuaifeng.zhao
 * @version v 0.1 
 */
public class TransCashDemo {

    /**
     * 取现交易调用实例
     * 
     */
    public static void executeEnchashment() {
        
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id",  nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 系统号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 商户订单号，需保证商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("mer_ord_id", "202104220932100001236");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 取现卡序列号
        dataMap.put("token_no", DemoConstants.TOKEN_NO);
        // 取现金额.单位:元
        dataMap.put("cash_amt", "0.02");
        // 入账类型
        // T0：当日到账；T1：T1次工作日到账；D1：次自然日到账；
        dataMap.put("into_acct_date_type", "T1");
        // 异步通知地址
        dataMap.put("notify_url", "virgo://http://www.vclinker.com");
        
        // 风控信息
        Map<String, Object> riskCheckInfo = new HashMap<String, Object>();
        // 经度
        riskCheckInfo.put("longitude", "");
        // 纬度
        riskCheckInfo.put("latitude", "");
        // 基站地址
        riskCheckInfo.put("base_station", "");
        
        // 风控信息 json String
        dataMap.put("risk_check_info",  JSON.toJSONString(riskCheckInfo));
        Map<String, Object> transInfo = new HashMap<>();
        try {
            System.out.println("取现交易请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            transInfo = BasePayClient.request(dataMap, "toppas.enchashment");
            // 多商户模式需指定merchantKey
            // transInfo = BasePayClient.request(dataMap, "toppas.enchashment", "merchantKey1");
            System.out.println("取现交易返回参数：" + JSON.toJSONString(transInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) transInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("00000100".equals(subRespCode)) {
            // 取现交易返回处理中
            String reqSeqId = (String) transInfo.get("req_seq_id");
            String merOrdId = (String) transInfo.get("mer_ord_id");
            System.out.println("reqSeqId :" + reqSeqId + ", merOrdId:" + merOrdId);
        } else {
            String subRespDesc = (String) transInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }
    

    /**
     * 出金交易查询调用实例
     * （即取现交易状态查询调用实例）
     */
    public static void executeCashQuery() {
        
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id",  nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 系统号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 原交易请求日期
        dataMap.put("trans_req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 原交易的商户订单号，trans_mer_ord_id和hf_seq_id二选一
        dataMap.put("trans_mer_ord_id", "202104220932100001236");
        // 原交易的汇付流水号，trans_mer_ord_id和hf_seq_id二选一
//        dataMap.put("hf_seq_id", "202103021008310123456789");
        Map<String, Object> transInfo = new HashMap<>();
        try {
            System.out.println("出金交易查询请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            transInfo = BasePayClient.request(dataMap, "topqur.cashQuery");
            // 多商户模式需指定merchantKey
            // transInfo = BasePayClient.request(dataMap, "topqur.cashQuery", "merchantKey1");
            System.out.println("出金交易查询返回参数：" + JSON.toJSONString(transInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) transInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("00000100".equals(subRespCode)) {
            // 取现交易返回处理中
            String hfSeqId = (String) transInfo.get("hf_seq_id");
            String transMerOrdId = (String) transInfo.get("trans_mer_ord_id");
            System.out.println("reqSeqId :" + hfSeqId + ", merOrdId:" + transMerOrdId);
        } else {
            String subRespDesc = (String) transInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }
}
