/**
 * 汇付天下有限公司
 * Copyright (c) 2006-2021 ChinaPnR,Inc.All Rights Reserved.
 */
package com.huifu.bspay.sdk.demo.trans;

import com.alibaba.fastjson.JSON;
import com.huifu.bspay.sdk.client.BasePayClient;
import com.huifu.bspay.sdk.demo.constants.DemoConstants;
import com.huifu.bspay.sdk.core.exception.BasePayException;


import java.util.HashMap;
import java.util.Map;

/**
 *
 * @author kefeng.zheng
 * @version v 0.1
 */
public class TransQueryDemo {

    /**
     * 交易查询接口调用实例
     * <p>
     *     扫码交易及银行卡分期交易的查询
     * </p>
     */
    public static void executeQuery () {
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 原始请求日期，指原交易的请求日期
        dataMap.put("req_date", "20210422");
        // 系统号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 以下指定原交易的唯一标识，支持5选1，可根据req_seq_id、party_order_id、out_trans_id、out_ord_id、hf_seq_id其中之一定位原交易
        // 原始请求流水号
        // dataMap.put("req_seq_id", "2021042209470201234567890");
        // dataMap.put("party_order_id", "03242104223522427700010");
        dataMap.put("out_trans_id", "4200001025202104226317337994");
        // 外部订单号，使用汇付机具，但订单号自行指定，此时订单号视为外部订单号
        // dataMap.put("out_ord_id", "");
        // dataMap.put("hf_seq_id", "002900TOP2A210422094704P067ac13907100000");

        Map<String, Object> transInfo = new HashMap<>();
        try {
            System.out.println("交易查询请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            transInfo = BasePayClient.request(dataMap, "topqur.transQuery");
            // 多商户模式需指定merchantKey
            // transInfo = BasePayClient.request(dataMap, "topqur.transQuery", "merchantKey1");
            System.out.println("交易查询返回参数：" + JSON.toJSONString(transInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) transInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 查询成功
            System.out.println("查询成功");
            // 获取原交易的状态
            String transStat = (String)transInfo.get("trans_stat");
            System.out.println("交易状态trans_stat=" + transStat);
        } else {
            String subRespDesc = (String) transInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }


    /**
     * 线上交易查询接口
     *
     * <p>
     *     适用于快捷、网银、手机网页支付交易查询
     * </p>
     *
     */
    public static void executeOnlineTransQuery(){
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 产品号
        dataMap.put("product_id", DemoConstants.DEMO_PRODUCT_ID);
        // 原交易请求日期
        dataMap.put("req_date", "20210422");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 支持根据原交易req_seq_id、hf_seq_id其中支一定位原交易，2选1
        // 原交易请求流水号
        dataMap.put("req_seq_id", "20210422onlinepage0001");

        Map<String, Object> transInfo = new HashMap<>();
        try {
            System.out.println("线上交易查询请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            transInfo = BasePayClient.request(dataMap, "top-online-ser.transQuery");
            // 多商户模式需指定merchantKey
            // transInfo = BasePayClient.request(dataMap, "top-online-ser.transQuery", "merchantKey1");
            System.out.println("线上交易查询返回参数：" + JSON.toJSONString(transInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) transInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            String transStat = (String) transInfo.get("trans_stat");
            // 业务处理成功
            System.out.println("处理成功, 交易结果为：" + transStat);
        } else {
            String subRespDesc = (String) transInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }

    }
}
