/**
 * 汇付天下有限公司
 * Copyright (c) 2006-2021 ChinaPnR,Inc.All Rights Reserved.
 */
package com.huifu.bspay.sdk.demo.trans;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.huifu.bspay.sdk.client.BasePayClient;
import com.huifu.bspay.sdk.demo.constants.DemoConstants;
import com.huifu.bspay.sdk.core.exception.BasePayException;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.HashMap;
import java.util.Map;

/**
 * 交易退款接口调用实例
 * @author kefeng.zheng
 * @version v 0.1
 */
public class TransRefundDemo {

    /**
     * 交易退款接口调用实例
     * <p>
     *     扫码交易及银行卡分期交易的退款
     * </p>
     */
    public static void executeRefund () {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 商户订单号，需保证商户下唯一，推荐采用日期时间+几位流水号的形式，可与req_seq_id相同
        dataMap.put("mer_ord_id", nowStr + "1234567890");
        // 系统号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 分账串，原路径退回无需上送
        JSONObject acctSplitBunch = new JSONObject();
        JSONArray acctInfos = new JSONArray();
        // 分账方1
        JSONObject acctInfo = new JSONObject();
        acctInfo.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        acctInfo.put("div_amt", "0.01");
        acctInfos.add(acctInfo);
        // 分账方2
        acctInfo = new JSONObject();
        acctInfo.put("huifu_id", DemoConstants.DIV_HUIFU_ID);
        acctInfo.put("div_amt", "0.01");
        acctInfos.add(acctInfo);
        acctSplitBunch.put("acct_infos", acctInfos);
        // dataMap.put("acct_split_bunch", acctSplitBunch);
        // 以下指定原交易的唯一标识，org_req_seq_id、hf_seq_id、party_order_id中3选1
        // 原交易请求流水号
        dataMap.put("org_req_seq_id", "2021042209470201234567890");
        // dataMap.put("hf_seq_id", "002900TOP2B210422092117P877ac132fd000000");
        // dataMap.put("party_order_id", "03242104216363871802189");
        // 原交易请求日期，指原交易的请求日期，当根据原交易流水号退货时必送
        dataMap.put("org_req_date", "20210422");
        // 退款金额
        dataMap.put("ord_amt", "0.02");
        // 设备信息
        JSONObject terminalDeviceInfo = new JSONObject();
        terminalDeviceInfo.put("device_type", "4");
        terminalDeviceInfo.put("device_ip", "139.207.19.246");
        dataMap.put("terminal_device_info", terminalDeviceInfo);
        // 备注
        dataMap.put("mark", "交易退货");
        // 扩展域
        dataMap.put("mer_priv", "扩展域");
        // 风控信息
        Map<String, String> riskMngInfo = new HashMap<>();
        riskMngInfo.put("subTradeType", "4300");
        Map<String, Object> riskCheckInfo = new HashMap<>();
        riskCheckInfo.put("riskMngInfo", riskMngInfo);
        riskCheckInfo.put("ipAddr", "139.207.19.246");
        // 注意，风控信息为JSON字符串
        // dataMap.put("risk_check_info", JSON.toJSONString(riskCheckInfo));
        dataMap.put("risk_check_info", riskCheckInfo);
        // 异步通知地址
        dataMap.put("notify_url", DemoConstants.NOTICE_URL);

        Map<String, Object> transRefundInfo = new HashMap<>();
        try {
            System.out.println("交易退款请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            transRefundInfo = BasePayClient.request(dataMap, "toprrc.refund");
            // 多商户模式需指定merchantKey
            // transRefundInfo = BasePayClient.request(dataMap, "toprrc.refund", "merchantKey1");
            System.out.println("交易查询返回参数：" + JSON.toJSONString(transRefundInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) transRefundInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
            // 获取退款交易的状态
            String transStat = (String) transRefundInfo.get("trans_stat");
            System.out.println("交易状态trans_stat=" + transStat);
        } else if ("00000100".equals(subRespCode)) {
            // 退款返回业务处理中后续可通过退款查询接口查询退款具体状态
            // 获取退款交易的状态
            String transStat = (String) transRefundInfo.get("trans_stat");
            System.out.println("交易状态trans_stat=" + transStat);
        } else {
            String subRespDesc = (String) transRefundInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }


    /**
     * 交易退款查询接口
     *
     * <p>
     *     当一笔退款返回处理中或者通信超时状态未明时调用退款查询接口获取退款详细
     * </p>
     *
     */
    public static void executeRefundQuery(){
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 原退款请求日期
        dataMap.put("req_date", "20210422");
        // 汇付分配系统号
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 以下上送原退款的唯一标识、mer_ord_id、req_seq_id、hf_seq_id、out_ord_id可4选1
        // 原退款请求流水号
        dataMap.put("req_seq_id", "2021042209502901234567890");

        Map<String, Object> refundInfo = new HashMap<>();
        try {
            System.out.println("交易退款查询请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            refundInfo = BasePayClient.request(dataMap, "topqur.refundQuery");
            // 多商户模式需指定merchantKey
            // refundInfo = BasePayClient.request(dataMap, "topqur.refundQuery", "merchantKey1");
            System.out.println("交易退款查询返回参数：" + JSON.toJSONString(refundInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) refundInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 查询处理成功
            String transStat = (String) refundInfo.get("trans_stat");
            System.out.println("查询成功, 交易结果为：" + transStat);
        } else {
            String subRespDesc = (String) refundInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }

    }

    /**
     * 线上交易退款
     */
    public static void executeOnlineRefund () {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", new SimpleDateFormat("yyyyMMdd").format(cl.getTime()));
        // 商户订单号，需保证商户下唯一，推荐采用日期时间+几位流水号的形式，可与req_seq_id相同
        dataMap.put("mer_ord_id", nowStr + "1234567890");
        // 系统号，由汇付分配
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        dataMap.put("org_req_seq_id", "20210422onlinepage0003");
        dataMap.put("org_req_date", "20210422");
        // 退款金额
        dataMap.put("ord_amt", "1.10");
        // 设备信息
        JSONObject terminalDeviceInfo = new JSONObject();
        terminalDeviceInfo.put("trx_device_type", "04");
        terminalDeviceInfo.put("trx_device_ip", "139.207.19.246");
        dataMap.put("device_info", terminalDeviceInfo);
        // 异步通知地址
        dataMap.put("notify_url", DemoConstants.NOTICE_URL);
        // 风控信息
        Map<String, String> riskMngInfo = new HashMap<>();
        riskMngInfo.put("subTradeType", "4300");
        Map<String, Object> riskCheckInfo = new HashMap<>();
        riskCheckInfo.put("riskMngInfo", riskMngInfo);
        riskCheckInfo.put("ipAddr", "139.207.19.246");
        // 注意，风控信息为JSON字符串
        dataMap.put("risk_check_info", JSON.toJSONString(riskCheckInfo));

        Map<String, Object> transRefundInfo = new HashMap<>();
        try {
            System.out.println("线上交易退款请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            transRefundInfo = BasePayClient.request(dataMap, "top-online-ser.refund");
            // 多商户模式需指定merchantKey
            // transRefundInfo = BasePayClient.request(dataMap, "top-online-ser.refund", "merchantKey1");
            System.out.println("线上交易查询返回参数：" + JSON.toJSONString(transRefundInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) transRefundInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
            // 获取退款交易的状态
            String transStat = (String) transRefundInfo.get("trans_stat");
            System.out.println("交易状态trans_stat=" + transStat);
        } else if ("00000100".equals(subRespCode)) {
            // 退款返回业务处理中后续可通过退款查询接口查询退款具体状态
            // 获取退款交易的状态
            String transStat = (String) transRefundInfo.get("trans_stat");
            System.out.println("交易状态trans_stat=" + transStat);
        } else {
            String subRespDesc = (String) transRefundInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 线上交易退款查询
     */
    public static void executeOnlineRefundQuery(){
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 原退款请求日期
        dataMap.put("req_date", "20210422");
        // 汇付分配系统号
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        dataMap.put("req_seq_id", "2021042215572601234567890");

        Map<String, Object> refundInfo = new HashMap<>();
        try {
            System.out.println("线上交易退款查询请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            refundInfo = BasePayClient.request(dataMap, "top-online-ser.refundQuery");
            // 多商户模式需指定merchantKey
            // refundInfo = BasePayClient.request(dataMap, "top-online-ser.refundQuery", "merchantKey1");
            System.out.println("线上交易退款查询返回参数：" + JSON.toJSONString(refundInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) refundInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 查询处理成功
            String transStat = (String) refundInfo.get("trans_stat");
            System.out.println("查询成功, 交易结果为：" + transStat);
        } else {
            String subRespDesc = (String) refundInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }

    }
}
