package com.huifu.bspay.sdk.demo.trans;

import com.alibaba.fastjson.JSON;
import com.huifu.bspay.sdk.client.BasePayClient;
import com.huifu.bspay.sdk.demo.constants.DemoConstants;
import com.huifu.bspay.sdk.core.exception.BasePayException;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @ClassName WalletEnchashmentDemo.java
 * @Description
 * @Author jili.hua
 * @Date 2021/4/15 16:16
 * @Version 1.0
 **/
public class WalletEnchashmentDemo {

    /**
     * 钱包取现接口
     */
    public static void executeWalletEnchashment() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", "20210412");
        // 产品号
        dataMap.put("product_id", DemoConstants.DEMO_PRODUCT_ID);
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 系统号
        dataMap.put("sys_id", DemoConstants.DEMO_SYS_ID);
        // 取现卡序列号
        dataMap.put("token_no", "5252255");
        // 取现金额
        dataMap.put("cash_amt", "1.00");
        // 入账类型 D0:当日到账;T1:下个工作日到账;D1:下个自然日到账
        dataMap.put("into_acct_date_type", "D0");
        // 异步通知地址
        dataMap.put("notify_url", DemoConstants.NOTICE_URL);

        Map<String, Object> walletEnchash = new HashMap<>();
        try {
            System.out.println("钱包取现请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            walletEnchash = BasePayClient.request(dataMap, "ssproxy.walletEnchashment");
            // 多商户模式需指定merchantKey
            // walletEnchash = BasePayClient.request(dataMap, "ssproxy.walletEnchashment", "merchantKey1");
            System.out.println("钱包取现返回参数：" + JSON.toJSONString(walletEnchash));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) walletEnchash.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) walletEnchash.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 钱包取现查询接口
     */
    public static void executeWalletEnchashmentQuery() {
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 交易确认请求流水号
        dataMap.put("req_seq_id", "01234567890");
        // 交易确认请求日期
        dataMap.put("req_date", "20210412");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 产品号
        dataMap.put("product_id", DemoConstants.DEMO_PRODUCT_ID);
        // 原取现交易请求流水号
        dataMap.put("org_req_seq_id", "1321313");
        // 原取现交易请求日期
        dataMap.put("org_req_date", "20210415");
        // 原取现交易系统号
        dataMap.put("org_sys_id", DemoConstants.DEMO_SYS_ID);

        Map<String, Object> walletEnchash = new HashMap<>();
        try {
            System.out.println("钱包取现查询请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            walletEnchash = BasePayClient.request(dataMap, "ssproxy.walletEnchashmentQuery");
            // 多商户模式需指定merchantKey
            // walletEnchash = BasePayClient.request(dataMap, "ssproxy.walletEnchashmentQuery", "merchantKey1");
            System.out.println("钱包取现查询返回参数：" + JSON.toJSONString(walletEnchash));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) walletEnchash.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) walletEnchash.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

}
