package com.huifu.bspay.sdk.demo.trans;

import com.alibaba.fastjson.JSON;
import com.huifu.bspay.sdk.client.BasePayClient;
import com.huifu.bspay.sdk.core.exception.BasePayException;
import com.huifu.bspay.sdk.demo.constants.DemoConstants;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @ClassName WalletFrzBalDemo.java
 * @Description
 * @Author jili.hua
 * @Date 2021/4/23 10:34
 * @Version 1.0
 **/
public class WalletFrzBalDemo {

    /**
     * 钱包余额冻结
     */
    public static void executeFrzwalletbal() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", "20210422");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 冻结金额
        dataMap.put("trans_amt", "0.01");

        Map<String, Object> acctPayment = new HashMap<>();
        try {
            System.out.println("钱包余额冻结请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            acctPayment = BasePayClient.request(dataMap, "ssproxy.frzWalletBal");
            // 多商户模式需指定merchantKey
            // acctPayment = BasePayClient.request(dataMap, "ssproxy.frzWalletBal", "merchantKey1");
            System.out.println("钱包余额冻结返回参数：" + JSON.toJSONString(acctPayment));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) acctPayment.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) acctPayment.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

    /**
     * 钱包余额解冻
     */
    public static void executeUnFrzwalletbal() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", "20210422");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 解冻明细列表
        List<Map<String, String>> unFrzInfos = new ArrayList<>();
        Map<String, String> unFrzInfo = new HashMap<>();
        unFrzInfo.put("org_req_seq_id","");
        unFrzInfo.put("org_req_dat","");
        unFrzInfo.put("org_sys_id","");
        unFrzInfos.add(unFrzInfo);
        dataMap.put("un_frz_infos", unFrzInfos);

        Map<String, Object> acctPayment = new HashMap<>();
        try {
            System.out.println("钱包余额解冻请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            acctPayment = BasePayClient.request(dataMap, "ssproxy.unFrzWalletBal");
            // 多商户模式需指定merchantKey
            // acctPayment = BasePayClient.request(dataMap, "ssproxy.unFrzWalletBal", "merchantKey1");
            System.out.println("钱包余额解冻返回参数：" + JSON.toJSONString(acctPayment));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) acctPayment.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else {
            String subRespDesc = (String) acctPayment.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }

}
