package com.huifu.bspay.sdk.demo.trans;

import com.alibaba.fastjson.JSON;
import com.huifu.bspay.sdk.client.BasePayClient;
import com.huifu.bspay.sdk.core.exception.BasePayException;
import com.huifu.bspay.sdk.demo.constants.DemoConstants;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @ClassName WapPaymentDemo.java
 * @Description
 * @Author jili.hua
 * @Date 2021/4/22 10:00
 * @Version 1.0
 **/
public class WapPaymentDemo {

    public static void executeWapPay() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", "20210412");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 银行卡号
        dataMap.put("card_no", DemoConstants.WAP_PAY_CARD_NO);
        // 交易金额
        dataMap.put("trans_amt", "200.00");
        // 异步通知地址
        dataMap.put("mer_notice_url", DemoConstants.NOTICE_URL);
        // 页面跳转地址
        dataMap.put("business_url", "http://www.xxx.com/getResp");
        // 失败页面跳转地址
        dataMap.put("business_fail_url", "http://www.xxx.com/getFailResp");
        // 订单有效期
        cl.add(Calendar.MINUTE, 2);
        dataMap.put("time_expire", sdf.format(cl.getTime()));

        // 网联扩展信息
        Map<String, String> extendPay = new HashMap<>();
        extendPay.put("pyer_trx_trm_tp", "02");// 01:电脑，02:手机，03:平板设备，04:可穿戴设备，05数字电视，06条码支付受理终端，99其他
        dataMap.put("extend_pay", JSON.toJSONString(extendPay));

        // 设备信息
        Map<String, String> deviceInfo = new HashMap<>();
        deviceInfo.put("trx_device_type", "01");// 01:手机，02:平板，03:手表，04:PC
        deviceInfo.put("trx_device_ip", "139.207.19.246 ");
        dataMap.put("device_info", JSON.toJSONString(deviceInfo));

        // 风控信息
        Map<String, String> riskMngInfo = new HashMap<>();
        riskMngInfo.put("subTradeType", "4300");
        Map<String, Object> riskCheckInfo = new HashMap<>();
        riskCheckInfo.put("riskMngInfo", riskMngInfo);
        riskCheckInfo.put("ipAddr", "139.207.19.246");
        // 注意，风控信息为JSON字符串
        dataMap.put("risk_check_info", JSON.toJSONString(riskCheckInfo));

        // 分账串
        List<Map<String, String>> acctInfos = new ArrayList<>();
        Map<String, String> acctInfo1 = new HashMap<>();
        // 分账商户号1
        acctInfo1.put("huifu_id", DemoConstants.DIV_HUIFU_ID);
        // 分账金额1
        acctInfo1.put("div_amt", "200.00");
        acctInfos.add(acctInfo1);
        Map<String, Object> acctSplitBunch = new HashMap<>();
        acctSplitBunch.put("acct_infos", acctInfos);
        dataMap.put("acct_split_bunch", acctSplitBunch);

        Map<String, Object> wapInfo = new HashMap<>();
        try {
            System.out.println("手机网页支付请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            wapInfo = BasePayClient.request(dataMap, "top-online-ser.wapPay");
            // 多商户模式需指定merchantKey
            // wapInfo = BasePayClient.request(dataMap, "top-online-ser.wapPay", "merchantKey1");
            System.out.println("手机网页支付返回参数：" + JSON.toJSONString(wapInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) wapInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("00000100".equals(subRespCode)) {
            // 交易处理中
            String payInfo = (String) wapInfo.get("form_html");// 银行提交页面html
            String formEncoding = (String) wapInfo.get("form_encoding");// 页面字符集
            System.out.println("form_html :" + payInfo + "，form_encoding :" + formEncoding);
        } else {
            String subRespDesc = (String) wapInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }


    public static void executeWapPayInstalments() {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
        Calendar cl = Calendar.getInstance();
        String nowStr = sdf.format(cl.getTime());
        // 参数组装
        Map<String, Object> dataMap = new HashMap<String, Object>();
        // 请求流水号，需保证当天商户下唯一，推荐采用日期时间+几位流水号的形式
        dataMap.put("req_seq_id", nowStr + "01234567890");
        // 请求日期，请求接口的日期，因服务器时间可能有差异，允许前后1天
        dataMap.put("req_date", "20210412");
        // 分配商户号
        dataMap.put("huifu_id", DemoConstants.DEMO_HUIFU_ID);
        // 银行卡号
        dataMap.put("card_no", DemoConstants.WAP_PAY_CARD_NO);
        // 交易金额
        dataMap.put("trans_amt", "200.00");
        // 异步通知地址
        dataMap.put("mer_notice_url", DemoConstants.NOTICE_URL);
        // 页面跳转地址
        dataMap.put("business_url", "http://www.xxx.com/getResp");
        // 失败页面跳转地址
        dataMap.put("business_fail_url", "http://www.xxx.com/getFailResp");
        // 订单有效期
        cl.add(Calendar.MINUTE, 2);
        dataMap.put("time_expire", sdf.format(cl.getTime()));

        // 网联扩展信息
        Map<String, String> extendPay = new HashMap<>();
        extendPay.put("pyer_trx_trm_tp", "02");// 01:电脑，02:手机，03:平板设备，04:可穿戴设备，05数字电视，06条码支付受理终端，99其他
        dataMap.put("extend_pay", JSON.toJSONString(extendPay));

        // 设备信息
        Map<String, String> deviceInfo = new HashMap<>();
        deviceInfo.put("trx_device_type", "01");// 01:手机，02:平板，03:手表，04:PC
        deviceInfo.put("trx_device_ip", "139.207.19.246 ");
        dataMap.put("device_info", JSON.toJSONString(deviceInfo));

        // 风控信息
        Map<String, String> riskMngInfo = new HashMap<>();
        riskMngInfo.put("subTradeType", "4300");
        Map<String, Object> riskCheckInfo = new HashMap<>();
        riskCheckInfo.put("riskMngInfo", riskMngInfo);
        riskCheckInfo.put("ipAddr", "139.207.19.246");
        // 注意，风控信息为JSON字符串
        dataMap.put("risk_check_info", JSON.toJSONString(riskCheckInfo));

        // 分账串
        List<Map<String, String>> acctInfos = new ArrayList<>();
        Map<String, String> acctInfo1 = new HashMap<>();
        // 分账商户号1
        acctInfo1.put("huifu_id", DemoConstants.DIV_HUIFU_ID);
        // 分账金额1
        acctInfo1.put("div_amt", "200.00");
        acctInfos.add(acctInfo1);
        Map<String, Object> acctSplitBunch = new HashMap<>();
        acctSplitBunch.put("acct_infos", acctInfos);
        dataMap.put("acct_split_bunch", acctSplitBunch);

        // 分期期数
        dataMap.put("instalments_num", "24");
        Map<String, Object> wapInfo = new HashMap<>();
        try {
            System.out.println("手机网页支付请求参数：" + JSON.toJSONString(dataMap));
            // 单商户模式可不指定merchantKey，会自动套用default配置
            wapInfo = BasePayClient.request(dataMap, "top-online-ser.wapPay");
            // 多商户模式需指定merchantKey
            // wapInfo = BasePayClient.request(dataMap, "top-online-ser.wapPay", "merchantKey1");
            System.out.println("手机网页支付返回参数：" + JSON.toJSONString(wapInfo));
        } catch (BasePayException e) {
            e.printStackTrace();
        }

        String subRespCode = (String) wapInfo.get("sub_resp_code");
        if ("00000000".equals(subRespCode)) {
            // 业务处理成功
            System.out.println("处理成功");
        } else if ("00000100".equals(subRespCode)) {
            // 交易处理中
            String payInfo = (String) wapInfo.get("form_html");// 银行提交页面html
            String formEncoding = (String) wapInfo.get("form_encoding");// 页面字符集
            System.out.println("form_html :" + payInfo + "，form_encoding :" + formEncoding);
        } else {
            String subRespDesc = (String) wapInfo.get("sub_resp_desc");
            // 业务处理失败
            System.out.println("处理失败，失败信息："  + subRespDesc);
        }
    }
}
